@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -10,6 +10,7 @@
  ****************************************************************************/
 
 #include <ArborX_LinearBVH.hpp>
+#include <ArborX_Point.hpp>
 #include <ArborX_Sphere.hpp>
 #include <ArborX_Version.hpp>
 
@@ -79,11 +80,11 @@ struct CountCallback
 {
   Kokkos::View<int *, MemorySpace> _counts;
 
-  template <typename Query>
-  KOKKOS_FUNCTION void operator()(Query const &query, int) const
+  template <typename Query, typename Value>
+  KOKKOS_FUNCTION void operator()(Query const &query, Value const &) const
   {
     auto const i = ArborX::getData(query);
-    Kokkos::atomic_increment(&_counts(i));
+    Kokkos::atomic_inc(&_counts(i));
   }
 };
 
@@ -142,11 +143,13 @@ int main(int argc, char *argv[])
     return distribution(generator);
   };
 
-  Kokkos::View<ArborX::Point *, MemorySpace> primitives(
+  using Point = ArborX::Point<3>;
+  using Sphere = ArborX::Sphere<3>;
+
+  Kokkos::View<Point *, MemorySpace> primitives(
       Kokkos::view_alloc(Kokkos::WithoutInitializing, "Benchmark::primitives"),
       num_primitives * num_problems);
-  Kokkos::View<decltype(ArborX::attach(ArborX::intersects(ArborX::Sphere{}),
-                                       int{})) *,
+  Kokkos::View<decltype(ArborX::attach(ArborX::intersects(Sphere{}), int{})) *,
                MemorySpace>
       predicates(Kokkos::view_alloc(Kokkos::WithoutInitializing,
                                     "Benchmark::predicates"),
@@ -156,7 +159,7 @@ int main(int argc, char *argv[])
     // Points are placed in a box [offset_x-1, offset_x+1] x [-1, 1] x [-1, 1]
     float offset_x = p * shift;
 
-    Kokkos::View<ArborX::Point *, MemorySpace> points(
+    Kokkos::View<Point *, MemorySpace> points(
         "Benchmark::points", std::max(num_primitives, num_predicates));
     auto points_host = Kokkos::create_mirror_view(points);
     for (int i = 0; i < (int)points.extent(0); ++i)
@@ -170,30 +173,32 @@ int main(int argc, char *argv[])
         Kokkos::subview(points, Kokkos::make_pair(0, num_primitives)));
     Kokkos::parallel_for(
         "Benchmark::construct_predicates",
-        Kokkos::RangePolicy<ExecutionSpace>(
-            ExecutionSpace{}, p * num_predicates, (p + 1) * num_predicates),
+        Kokkos::RangePolicy(ExecutionSpace{}, p * num_predicates,
+                            (p + 1) * num_predicates),
         KOKKOS_LAMBDA(int i) {
-          predicates(i) =
-              ArborX::attach(ArborX::intersects(ArborX::Sphere{
-                                 points(i - p * num_predicates), r}),
-                             i);
+          predicates(i) = ArborX::attach(
+              ArborX::intersects(Sphere{points(i - p * num_predicates), r}), i);
         });
   }
 
   InstanceManager<ExecutionSpace> instance_manager(num_exec_spaces);
   auto const &instances = instance_manager.get_instances();
 
-  std::vector<ArborX::BVH<MemorySpace>> trees;
+  std::vector<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                              ArborX::PairValueIndex<Point>>>
+      trees;
   for (int p = 0; p < num_problems; ++p)
   {
     auto const &exec_space = instances[p % num_exec_spaces];
 
     trees.emplace_back(
-        exec_space, Kokkos::subview(primitives, Kokkos::pair<int, int>(
-                                                    p * num_primitives,
-                                                    (p + 1) * num_primitives)));
+        exec_space,
+        ArborX::Experimental::attach_indices(Kokkos::subview(
+            primitives, Kokkos::pair<int, int>(p * num_primitives,
+                                               (p + 1) * num_primitives))));
   }
-  ArborX::BVH<MemorySpace> tree(instances[0], primitives);
+  ArborX::BoundingVolumeHierarchy tree(
+      instances[0], ArborX::Experimental::attach_indices(primitives));
 
   Kokkos::View<int *, MemorySpace> counts("Benchmark::counts",
                                           num_predicates * num_problems);
