@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -9,12 +9,12 @@
  * SPDX-License-Identifier: BSD-3-Clause                                    *
  ****************************************************************************/
 
-#include <ArborX_DetailsKokkosExtStdAlgorithms.hpp>
-#include <ArborX_DetailsKokkosExtVersion.hpp>
-#include <ArborX_DetailsSortUtils.hpp>
-#include <ArborX_DetailsUnionFind.hpp>
-#include <ArborX_DetailsUtils.hpp>
 #include <ArborX_Version.hpp>
+#include <detail/ArborX_UnionFind.hpp>
+#include <kokkos_ext/ArborX_KokkosExtStdAlgorithms.hpp>
+#include <kokkos_ext/ArborX_KokkosExtVersion.hpp>
+#include <misc/ArborX_SortUtils.hpp>
+#include <misc/ArborX_Utils.hpp>
 
 #include <Kokkos_Core.hpp>
 #include <Kokkos_Random.hpp>
@@ -49,8 +49,7 @@ buildEdges(AllowLoops, ExecutionSpace const &exec_space, int num_edges)
 
   Kokkos::Random_XorShift1024_Pool<ExecutionSpace> rand_pool(1984);
   Kokkos::parallel_for(
-      "Benchmark::init_edges",
-      Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0, num_edges),
+      "Benchmark::init_edges", Kokkos::RangePolicy(exec_space, 0, num_edges),
       KOKKOS_LAMBDA(unsigned i) {
         auto rand_gen = rand_pool.get_state();
         do
@@ -77,8 +76,7 @@ buildEdges(DisallowLoops, ExecutionSpace const &exec_space, int num_edges)
       num_edges);
   Kokkos::parallel_for(
       "Benchmark::init_random_values",
-      Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0, num_edges),
-      KOKKOS_LAMBDA(int i) {
+      Kokkos::RangePolicy(exec_space, 0, num_edges), KOKKOS_LAMBDA(int i) {
         auto rand_gen = rand_pool.get_state();
         random_values(i) = rand_gen.rand();
         rand_pool.free_state(rand_gen);
@@ -91,8 +89,7 @@ buildEdges(DisallowLoops, ExecutionSpace const &exec_space, int num_edges)
                          "Benchmark::edges"),
       num_edges);
   Kokkos::parallel_for(
-      "Benchmark::init_edges",
-      Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0, num_edges),
+      "Benchmark::init_edges", Kokkos::RangePolicy(exec_space, 0, num_edges),
       KOKKOS_LAMBDA(unsigned i) {
         auto rand_gen = rand_pool.get_state();
         edges(permute(i)) = {rand_gen.urand() % (i + 1), i + 1};
@@ -137,8 +134,7 @@ void BM_union_find(benchmark::State &state)
 
     Kokkos::parallel_for(
         "Benchmark::union-find",
-        Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0, edges.size()),
-        KOKKOS_LAMBDA(int e) {
+        Kokkos::RangePolicy(exec_space, 0, edges.size()), KOKKOS_LAMBDA(int e) {
           int i = edges(e).source;
           int j = edges(e).target;
 
