@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -35,28 +35,27 @@ struct Spheres
 };
 
 template <>
-struct ArborX::AccessTraits<PointCloud, ArborX::PrimitivesTag>
+struct ArborX::AccessTraits<PointCloud>
 {
   static KOKKOS_FUNCTION std::size_t size(PointCloud const &cloud)
   {
     return cloud.N;
   }
-  static KOKKOS_FUNCTION ArborX::Point get(PointCloud const &cloud,
-                                           std::size_t i)
+  static KOKKOS_FUNCTION auto get(PointCloud const &cloud, std::size_t i)
   {
-    return {{cloud.d_x[i], cloud.d_y[i], cloud.d_z[i]}};
+    return ArborX::Point{cloud.d_x[i], cloud.d_y[i], cloud.d_z[i]};
   }
   using memory_space = Kokkos::CudaSpace;
 };
 
 template <>
-struct ArborX::AccessTraits<Spheres, ArborX::PredicatesTag>
+struct ArborX::AccessTraits<Spheres>
 {
   static KOKKOS_FUNCTION std::size_t size(Spheres const &d) { return d.N; }
   static KOKKOS_FUNCTION auto get(Spheres const &d, std::size_t i)
   {
     return ArborX::intersects(
-        ArborX::Sphere{{{d.d_x[i], d.d_y[i], d.d_z[i]}}, d.d_r[i]});
+        ArborX::Sphere{ArborX::Point{d.d_x[i], d.d_y[i], d.d_z[i]}, d.d_r[i]});
   }
   using memory_space = Kokkos::CudaSpace;
 };
@@ -80,18 +79,20 @@ int main(int argc, char *argv[])
   cudaMemcpyAsync(d_a, a.data(), sizeof(a), cudaMemcpyHostToDevice, stream);
 
   Kokkos::Cuda cuda{stream};
-  ArborX::BVH<Kokkos::CudaSpace> bvh{cuda, PointCloud{d_a, d_a, d_a, N}};
+  ArborX::BoundingVolumeHierarchy bvh{cuda, PointCloud{d_a, d_a, d_a, N}};
 
-  Kokkos::View<int *, Kokkos::CudaSpace> indices("Example::indices", 0);
+  Kokkos::View<ArborX::Point<3> *, Kokkos::CudaSpace> points("Example::points",
+                                                             0);
   Kokkos::View<int *, Kokkos::CudaSpace> offset("Example::offset", 0);
-  ArborX::query(bvh, cuda, Spheres{d_a, d_a, d_a, d_a, N}, indices, offset);
+  ArborX::query(bvh, cuda, Spheres{d_a, d_a, d_a, d_a, N}, points, offset);
 
   Kokkos::parallel_for(
-      "Example::print_indices", Kokkos::RangePolicy<Kokkos::Cuda>(cuda, 0, N),
+      "Example::print_points", Kokkos::RangePolicy(cuda, 0, N),
       KOKKOS_LAMBDA(int i) {
         for (int j = offset(i); j < offset(i + 1); ++j)
         {
-          printf("%i %i\n", i, indices(j));
+          printf("%i: (%.1f, %.1f, %.1f)\n", i, points(j)[0], points(j)[1],
+                 points(j)[2]);
         }
       });
 
