@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -29,40 +29,36 @@ struct NearestToOrigin
 };
 
 template <>
-struct ArborX::AccessTraits<FirstOctant, ArborX::PredicatesTag>
+struct ArborX::AccessTraits<FirstOctant>
 {
   static KOKKOS_FUNCTION std::size_t size(FirstOctant) { return 1; }
   static KOKKOS_FUNCTION auto get(FirstOctant, std::size_t)
   {
-    return ArborX::intersects(ArborX::Box{{{0, 0, 0}}, {{1, 1, 1}}});
+    return ArborX::intersects(ArborX::Box<3>{{0.f, 0.f, 0.f}, {1.f, 1.f, 1.f}});
   }
   using memory_space = MemorySpace;
 };
 
 template <>
-struct ArborX::AccessTraits<NearestToOrigin, ArborX::PredicatesTag>
+struct ArborX::AccessTraits<NearestToOrigin>
 {
   static KOKKOS_FUNCTION std::size_t size(NearestToOrigin) { return 1; }
   static KOKKOS_FUNCTION auto get(NearestToOrigin d, std::size_t)
   {
-    return ArborX::nearest(ArborX::Point{0, 0, 0}, d.k);
+    return ArborX::nearest(ArborX::Point{0.f, 0.f, 0.f}, d.k);
   }
   using memory_space = MemorySpace;
 };
 
 struct PrintfCallback
 {
-  template <typename Predicate, typename OutputFunctor>
-  KOKKOS_FUNCTION void operator()(Predicate, int primitive,
+  template <typename Predicate, typename Value, typename OutputFunctor>
+  KOKKOS_FUNCTION void operator()(Predicate, Value const &value,
                                   OutputFunctor const &out) const
   {
-#if KOKKOS_VERSION >= 40200
-    using Kokkos::printf;
-#elif defined(__SYCL_DEVICE_ONLY__)
-    using sycl::ext::oneapi::experimental::printf;
-#endif
-    printf("Found %d from functor\n", primitive);
-    out(primitive);
+    auto const index = value.index;
+    Kokkos::printf("Found %d from functor\n", index);
+    out(index);
   }
 };
 
@@ -70,22 +66,24 @@ int main(int argc, char *argv[])
 {
   Kokkos::ScopeGuard guard(argc, argv);
 
+  using Point = ArborX::Point<3>;
+
   int const n = 100;
-  std::vector<ArborX::Point> points;
+  std::vector<Point> points;
   // Fill vector with random points in [-1, 1]^3
   std::uniform_real_distribution<float> dis{-1., 1.};
   std::default_random_engine gen;
   auto rd = [&]() { return dis(gen); };
   std::generate_n(std::back_inserter(points), n, [&]() {
-    return ArborX::Point{rd(), rd(), rd()};
+    return Point{rd(), rd(), rd()};
   });
 
-  ArborX::BVH<MemorySpace> bvh{
+  ArborX::BoundingVolumeHierarchy bvh{
       ExecutionSpace{},
-      Kokkos::create_mirror_view_and_copy(
+      ArborX::Experimental::attach_indices(Kokkos::create_mirror_view_and_copy(
           MemorySpace{},
-          Kokkos::View<ArborX::Point *, Kokkos::HostSpace,
-                       Kokkos::MemoryUnmanaged>(points.data(), points.size()))};
+          Kokkos::View<Point *, Kokkos::HostSpace, Kokkos::MemoryUnmanaged>(
+              points.data(), points.size())))};
 
   {
     Kokkos::View<int *, MemorySpace> values("Example::values", 0);
@@ -95,14 +93,8 @@ int main(int argc, char *argv[])
 #ifndef __NVCC__
     ArborX::query(
         bvh, ExecutionSpace{}, FirstOctant{},
-        KOKKOS_LAMBDA(auto /*predicate*/, int primitive,
-                      auto /*output_functor*/) {
-#if KOKKOS_VERSION >= 40200
-          using Kokkos::printf;
-#elif defined(__SYCL_DEVICE_ONLY__)
-          using sycl::ext::oneapi::experimental::printf;
-#endif
-          printf("Found %d from generic lambda\n", primitive);
+        KOKKOS_LAMBDA(auto /*predicate*/, auto value, auto /*output_functor*/) {
+          Kokkos::printf("Found %d from generic lambda\n", value.index);
         },
         values, offsets);
 #endif
@@ -117,14 +109,8 @@ int main(int argc, char *argv[])
 #ifndef __NVCC__
     ArborX::query(
         bvh, ExecutionSpace{}, NearestToOrigin{k},
-        KOKKOS_LAMBDA(auto /*predicate*/, int primitive,
-                      auto /*output_functor*/) {
-#if KOKKOS_VERSION >= 40200
-          using Kokkos::printf;
-#elif defined(__SYCL_DEVICE_ONLY__)
-          using sycl::ext::oneapi::experimental::printf;
-#endif
-          printf("Found %d from generic lambda\n", primitive);
+        KOKKOS_LAMBDA(auto /*predicate*/, auto value, auto /*output_functor*/) {
+          Kokkos::printf("Found %d from generic lambda\n", value.index);
         },
         values, offsets);
 #endif
@@ -138,13 +124,8 @@ int main(int argc, char *argv[])
 #ifndef __NVCC__
     bvh.query(
         ExecutionSpace{}, FirstOctant{},
-        KOKKOS_LAMBDA(auto /*predicate*/, int j) {
-#if KOKKOS_VERSION >= 40200
-          using Kokkos::printf;
-#elif defined(__SYCL_DEVICE_ONLY__)
-          using sycl::ext::oneapi::experimental::printf;
-#endif
-          printf("%d %d %d\n", ++c(), -1, j);
+        KOKKOS_LAMBDA(auto /*predicate*/, auto value) {
+          Kokkos::printf("%d %d %d\n", ++c(), -1, value.index);
         });
 #endif
   }
