@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -60,16 +60,17 @@ struct Rays
 template <typename MemorySpace>
 struct DepositEnergy
 {
-  Kokkos::View<ArborX::Box *, MemorySpace> _boxes;
+  Kokkos::View<ArborX::Box<3> *, MemorySpace> _boxes;
   Kokkos::View<float *, MemorySpace> _ray_energy;
   Kokkos::View<float *, MemorySpace> _energy;
 
-  template <typename Predicate>
+  template <typename Predicate, typename Value>
   KOKKOS_FUNCTION void operator()(Predicate const &predicate,
-                                  int const primitive_index) const
+                                  Value const &value) const
   {
     float length;
     float entrylength;
+    int const primitive_index = value.index;
     auto const &ray = ArborX::getGeometry(predicate);
     auto const &box = _boxes(primitive_index);
     int const predicate_index = ArborX::getData(predicate);
@@ -86,8 +87,7 @@ struct DepositEnergy
 } // namespace OrderedIntersectsBased
 
 template <typename MemorySpace>
-struct ArborX::AccessTraits<OrderedIntersectsBased::Rays<MemorySpace>,
-                            ArborX::PredicatesTag>
+struct ArborX::AccessTraits<OrderedIntersectsBased::Rays<MemorySpace>>
 {
   using memory_space = MemorySpace;
   using size_type = std::size_t;
@@ -147,15 +147,16 @@ struct IntersectedCell : public IntersectedCellForSorting
 template <typename MemorySpace>
 struct AccumulateRaySphereIntersections
 {
-  Kokkos::View<ArborX::Box *, MemorySpace> _boxes;
+  Kokkos::View<ArborX::Box<3> *, MemorySpace> _boxes;
 
-  template <typename Predicate, typename OutputFunctor>
+  template <typename Predicate, typename Value, typename OutputFunctor>
   KOKKOS_FUNCTION void operator()(Predicate const &predicate,
-                                  int const primitive_index,
+                                  Value const &value,
                                   OutputFunctor const &out) const
   {
     float length;
     float entrylength;
+    int const primitive_index = value.index;
     auto const &ray = ArborX::getGeometry(predicate);
     auto const &box = _boxes(primitive_index);
     int const predicate_index = ArborX::getData(predicate);
@@ -218,14 +219,13 @@ int main(int argc, char *argv[])
 
   Kokkos::Profiling::pushRegion("Example::problem_setup");
   Kokkos::Profiling::pushRegion("Example::make_grid");
-  Kokkos::View<ArborX::Box *, MemorySpace> boxes(
+  Kokkos::View<ArborX::Box<3> *, MemorySpace> boxes(
       Kokkos::view_alloc(exec_space, Kokkos::WithoutInitializing,
                          "Example::boxes"),
       num_boxes);
   Kokkos::parallel_for(
       "Example::initialize_boxes",
-      Kokkos::MDRangePolicy<Kokkos::Rank<3>, ExecutionSpace>(
-          exec_space, {0, 0, 0}, {nx, ny, nz}),
+      Kokkos::MDRangePolicy(exec_space, {0, 0, 0}, {nx, ny, nz}),
       KOKKOS_LAMBDA(int i, int j, int k) {
         int const box_id = i + nx * j + nx * ny * k;
         boxes(box_id) = {{i * dx, j * dy, k * dz},
@@ -246,8 +246,7 @@ int main(int argc, char *argv[])
 
     Kokkos::parallel_for(
         "Example::initialize_rays",
-        Kokkos::MDRangePolicy<Kokkos::Rank<2>, ExecutionSpace>(
-            exec_space, {0, 0}, {num_boxes, rays_per_box}),
+        Kokkos::MDRangePolicy(exec_space, {0, 0}, {num_boxes, rays_per_box}),
         KOKKOS_LAMBDA(size_t const i, size_t const j) {
           // The origins of rays are uniformly distributed in the boxes. The
           // direction vectors are uniformly sampling of a full sphere.
@@ -256,21 +255,23 @@ int main(int argc, char *argv[])
           using Kokkos::sin;
           using Kokkos::acos;
 
-          ArborX::Box const &b = boxes(i);
-          ArborX::Point origin{
-              b.minCorner()[0] +
-                  Kokkos::rand<GeneratorType, float>::draw(g, dx),
-              b.minCorner()[1] +
-                  Kokkos::rand<GeneratorType, float>::draw(g, dy),
-              b.minCorner()[2] +
-                  Kokkos::rand<GeneratorType, float>::draw(g, dz)};
+          using Point = typename ArborX::Experimental::Ray::Point;
+          using Vector = typename ArborX::Experimental::Ray::Vector;
+
+          auto const &b = boxes(i);
+          Point origin{b.minCorner()[0] +
+                           Kokkos::rand<GeneratorType, float>::draw(g, dx),
+                       b.minCorner()[1] +
+                           Kokkos::rand<GeneratorType, float>::draw(g, dy),
+                       b.minCorner()[2] +
+                           Kokkos::rand<GeneratorType, float>::draw(g, dz)};
 
           float upsilon = Kokkos::rand<GeneratorType, float>::draw(
               g, 2.f * Kokkos::numbers::pi_v<float>);
           float theta =
               acos(1 - 2 * Kokkos::rand<GeneratorType, float>::draw(g));
-          ArborX::Experimental::Vector direction{
-              cos(upsilon) * sin(theta), sin(upsilon) * sin(theta), cos(theta)};
+          Vector direction{cos(upsilon) * sin(theta), sin(upsilon) * sin(theta),
+                           cos(theta)};
 
           rays(j + i * rays_per_box) =
               ArborX::Experimental::Ray{origin, direction};
@@ -282,7 +283,8 @@ int main(int argc, char *argv[])
   Kokkos::Profiling::popRegion();
 
   // Construct BVH
-  ArborX::BVH<MemorySpace> bvh{exec_space, boxes};
+  ArborX::BoundingVolumeHierarchy bvh{
+      exec_space, ArborX::Experimental::attach_indices(boxes)};
 
   // OrderedIntersects-based approach
   Kokkos::View<float *, MemorySpace> energy_ordered_intersects;
@@ -321,7 +323,7 @@ int main(int argc, char *argv[])
                    values.size());
     Kokkos::parallel_for(
         "Example::copy sort_array",
-        Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0, values.size()),
+        Kokkos::RangePolicy(exec_space, 0, values.size()),
         KOKKOS_LAMBDA(int i) { sort_array(i) = values(i); });
     Kokkos::Profiling::pushRegion("Example::sorting by key");
     // FIXME Users should not need to reach into the Details namespace.
@@ -350,8 +352,7 @@ int main(int argc, char *argv[])
         "Example::energy_intersects", num_boxes);
     Kokkos::parallel_for(
         "Example::deposit_energy",
-        Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0,
-                                            rays_per_box * num_boxes),
+        Kokkos::RangePolicy(exec_space, 0, rays_per_box * num_boxes),
         KOKKOS_LAMBDA(int i) {
           float ray_energy = (total_energy * dx * dy * dz) / rays_per_box;
           for (int j = offsets(i); j < offsets(i + 1); ++j)
@@ -372,8 +373,7 @@ int main(int argc, char *argv[])
   int n_errors;
   float rel_tol = 1.e-5;
   Kokkos::parallel_reduce(
-      "Example::compare",
-      Kokkos::RangePolicy<ExecutionSpace>(exec_space, 0, num_boxes),
+      "Example::compare", Kokkos::RangePolicy(exec_space, 0, num_boxes),
       KOKKOS_LAMBDA(int i, int &error) {
         using Kokkos::fabs;
         float const abs_error =
@@ -381,14 +381,9 @@ int main(int argc, char *argv[])
             fabs(energy_intersects(i));
         if (abs_error > rel_tol * fabs(energy_intersects(i)))
         {
-#if KOKKOS_VERSION >= 40200
-          using Kokkos::printf;
-#elif defined(__SYCL_DEVICE_ONLY__)
-          using sycl::ext::oneapi::experimental::printf;
-#endif
-          printf("%d: %f != %f, relative error: %f\n", i,
-                 energy_ordered_intersects(i), energy_intersects(i),
-                 abs_error / fabs(energy_intersects(i)));
+          Kokkos::printf("%d: %f != %f, relative error: %f\n", i,
+                         energy_ordered_intersects(i), energy_intersects(i),
+                         abs_error / fabs(energy_intersects(i)));
           ++error;
         }
       },
