@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -12,73 +12,28 @@
 #define ARBORX_RAY_HPP
 
 #include <ArborX_Box.hpp>
-#include <ArborX_DetailsAlgorithms.hpp> // equal
-#include <ArborX_DetailsKokkosExtArithmeticTraits.hpp>
-#include <ArborX_DetailsKokkosExtSwap.hpp>
-#include <ArborX_HyperTriangle.hpp>
 #include <ArborX_Point.hpp>
 #include <ArborX_Sphere.hpp>
+#include <ArborX_Triangle.hpp>
+#include <algorithms/ArborX_Equals.hpp>
+#include <kokkos_ext/ArborX_KokkosExtArithmeticTraits.hpp>
+#include <misc/ArborX_Vector.hpp>
 
-#include <Kokkos_Macros.hpp>
-#if KOKKOS_VERSION >= 40200
 #include <Kokkos_Assert.hpp> // KOKKOS_ASSERT
-#else
-#include <impl/Kokkos_Error.hpp> // KOKKOS_ASSERT
-#endif
+#include <Kokkos_Macros.hpp>
+#include <Kokkos_MinMax.hpp>
+#include <Kokkos_Swap.hpp>
 
 #include <cmath>
 
 namespace ArborX::Experimental
 {
 
-struct Vector : private Point
-{
-  using Point::Point;
-  using Point::operator[];
-  friend KOKKOS_FUNCTION constexpr bool operator==(Vector const &v,
-                                                   Vector const &w)
-  {
-    return v[0] == w[0] && v[1] == w[1] && v[2] == w[2];
-  }
-};
-
-template <typename Point1, typename Point2>
-KOKKOS_INLINE_FUNCTION constexpr std::enable_if_t<
-    GeometryTraits::is_point<Point1>::value &&
-        GeometryTraits::is_point<Point2>::value &&
-        GeometryTraits::dimension_v<Point1> == 3 &&
-        GeometryTraits::dimension_v<Point2> == 3,
-    Vector>
-makeVector(Point1 const &begin, Point2 const &end)
-{
-  Vector v;
-  for (int d = 0; d < 3; ++d)
-  {
-    v[d] = end[d] - begin[d];
-  }
-  return v;
-}
-
-KOKKOS_INLINE_FUNCTION constexpr auto dotProduct(Vector const &v,
-                                                 Vector const &w)
-{
-  return v[0] * w[0] + v[1] * w[1] + v[2] * w[2];
-}
-
-KOKKOS_INLINE_FUNCTION constexpr Vector crossProduct(Vector const &v,
-                                                     Vector const &w)
-{
-  return {v[1] * w[2] - v[2] * w[1], v[2] * w[0] - v[0] * w[2],
-          v[0] * w[1] - v[1] * w[0]};
-}
-
-KOKKOS_INLINE_FUNCTION constexpr bool equals(Vector const &v, Vector const &w)
-{
-  return v == w;
-}
-
 struct Ray
 {
+  using Point = ArborX::Point<3>;
+  using Vector = ArborX::Details::Vector<3>;
+
   Point _origin = {};
   Vector _direction = {};
 
@@ -90,7 +45,10 @@ struct Ray
       : _origin(origin)
       , _direction(direction)
   {
-    normalize(_direction);
+    // Normalize direction using higher precision. Using `float` by default
+    // creates a large error in the norm that affects ray tracing for
+    // triangles.
+    _direction = Details::normalize<double>(_direction);
   }
 
   KOKKOS_FUNCTION
@@ -104,58 +62,32 @@ struct Ray
 
   KOKKOS_FUNCTION
   constexpr Vector const &direction() const { return _direction; }
-
-private:
-  // We would like to use Scalar defined as:
-  // using Scalar = std::decay_t<decltype(std::declval<Vector>()[0])>;
-  // However, this means using float to compute the norm. This creates a large
-  // error in the norm that affects ray tracing for triangles. Casting the
-  // norm from double to float once it has been computed is not enough to
-  // improve the value of the normalized vector. Thus, the norm has to return a
-  // double.
-  using Scalar = double;
-
-  KOKKOS_FUNCTION
-  static Scalar norm(Vector const &v)
-  {
-    Scalar sq{};
-    for (int d = 0; d < 3; ++d)
-      sq += static_cast<Scalar>(v[d]) * static_cast<Scalar>(v[d]);
-    return std::sqrt(sq);
-  }
-
-  KOKKOS_FUNCTION static void normalize(Vector &v)
-  {
-    auto const magv = norm(v);
-    KOKKOS_ASSERT(magv > 0);
-    for (int d = 0; d < 3; ++d)
-      v[d] /= magv;
-  }
 };
 
 KOKKOS_INLINE_FUNCTION
 constexpr bool equals(Ray const &l, Ray const &r)
 {
   using ArborX::Details::equals;
-  return equals(l.origin(), r.origin()) && equals(l.direction(), r.direction());
+  return equals(l.origin(), r.origin()) && l.direction() == r.direction();
 }
 
 KOKKOS_INLINE_FUNCTION
-Point returnCentroid(Ray const &ray) { return ray.origin(); }
+auto returnCentroid(Ray const &ray) { return ray.origin(); }
 
 // The ray-box intersection algorithm is based on [1]. Their 'efficient slag'
 // algorithm checks the intersections both in front and behind the ray.
 //
 // There are few issues here. First, when a ray direction is aligned with one
-// of the axis, a division by zero will occur. This is fine, as usually it
-// results in +inf or -inf, which are treated correctly. However, it also leads
-// to the second situation, when it is 0/0 which occurs when the ray's origin
-// in that dimension is on the same plane as one of the corners of the box
-// (i.e., if inv_ray_dir[d] == 0 && (min_corner[d] == origin[d] || max_corner[d]
-// == origin[d])). This leads to NaN, which are not treated correctly (unless,
-// as in [1], the underlying min/max functions are able to ignore them). The
-// issue is discussed in more details in [2] and the website (key word: A
-// minimal ray-tracer: rendering simple shapes).
+// of the axis, a division by zero will occur. The algorithm can treat -inf and
+// +inf correctly but some user codes enable floating point exceptions which is
+// problematic. Instead of dividing by zero, we set the values to -inf/+inf
+// ourselves. The second issue happens when it is 0/0 which occurs when the
+// ray's origin in that dimension is on the same plane as one of the corners of
+// the box (i.e., if inv_ray_dir[d] == 0 && (min_corner[d] == origin[d] ||
+// max_corner[d] == origin[d])). This leads to NaN, which are not treated
+// correctly unless, as in [1], the underlying min/max functions are able to
+// ignore them. This is what we do manually using `continue`. The issue is
+// discussed in more details in [2].
 //
 // [1] Majercik, A., Crassin, C., Shirley, P., & McGuire, M. (2018). A ray-box
 // intersection algorithm and efficient dynamic voxel rendering. Journal of
@@ -165,7 +97,7 @@ Point returnCentroid(Ray const &ray) { return ray.origin(); }
 // efficient and robust ray-box intersection algorithm. In ACM SIGGRAPH 2005
 // Courses (pp. 9-es).
 KOKKOS_INLINE_FUNCTION
-bool intersection(Ray const &ray, Box const &box, float &tmin, float &tmax)
+bool intersection(Ray const &ray, Box<3> const &box, float &tmin, float &tmax)
 {
   auto const &min = box.minCorner();
   auto const &max = box.maxCorner();
@@ -181,7 +113,23 @@ bool intersection(Ray const &ray, Box const &box, float &tmin, float &tmax)
   {
     float tdmin;
     float tdmax;
-    if (dir[d] >= 0)
+    if (dir[d] == 0)
+    {
+      float const min_orig = min[d] - orig[d];
+
+      // minx_orig is zero then max_orig is also zero
+      if (min_orig == 0)
+      {
+        continue;
+      }
+
+      float const max_orig = max[d] - orig[d];
+
+      // signbit returns false for +0.0 and true for -0.0
+      tdmin = std::signbit(dir[d] * max_orig) ? inf : -inf;
+      tdmax = std::signbit(dir[d] * min_orig) ? inf : -inf;
+    }
+    else if (dir[d] > 0)
     {
       tdmin = (min[d] - orig[d]) / dir[d];
       tdmax = (max[d] - orig[d]) / dir[d];
@@ -200,7 +148,7 @@ bool intersection(Ray const &ray, Box const &box, float &tmin, float &tmax)
 }
 
 KOKKOS_INLINE_FUNCTION
-bool intersects(Ray const &ray, Box const &box)
+bool intersects(Ray const &ray, Box<3> const &box)
 {
   float tmin;
   float tmax;
@@ -210,7 +158,7 @@ bool intersects(Ray const &ray, Box const &box)
 
 // The function returns the index of the largest
 // component of the direction vector.
-KOKKOS_INLINE_FUNCTION int findLargestComp(Vector const &dir)
+KOKKOS_INLINE_FUNCTION int findLargestComp(typename Ray::Vector const &dir)
 {
   int kz = 0;
 
@@ -243,9 +191,9 @@ KOKKOS_INLINE_FUNCTION int findLargestComp(Vector const &dir)
 // implementation avoids explicitly defining rotation angles
 // and directions. The following ray-edge intersection will
 // be in the x*-y* plane.
-KOKKOS_INLINE_FUNCTION Point rotate2D(Point const &point)
+KOKKOS_INLINE_FUNCTION auto rotate2D(Ray::Point const &point)
 {
-  Point point_star;
+  Ray::Point point_star;
   float r = std::sqrt(point[0] * point[0] + point[1] * point[1]);
   if (point[0] != 0)
   {
@@ -265,8 +213,8 @@ KOKKOS_INLINE_FUNCTION Point rotate2D(Point const &point)
 // the transformed and rotated triangle edges
 // The algorithm is described in
 // https://en.wikipedia.org/wiki/Line%E2%80%93line_intersection#Given_two_points_on_each_line_segment
-KOKKOS_INLINE_FUNCTION bool rayEdgeIntersect(Point const &edge_vertex_1,
-                                             Point const &edge_vertex_2,
+KOKKOS_INLINE_FUNCTION bool rayEdgeIntersect(Ray::Point const &edge_vertex_1,
+                                             Ray::Point const &edge_vertex_2,
                                              float &t)
 {
   float x3 = edge_vertex_1[0];
@@ -301,12 +249,13 @@ KOKKOS_INLINE_FUNCTION bool rayEdgeIntersect(Point const &edge_vertex_1,
 // when the ray and the triangle is coplanar.
 // In the paper, they just need the boolean return.
 KOKKOS_INLINE_FUNCTION
-bool intersection(Ray const &ray,
-                  ExperimentalHyperGeometry::Triangle<3> const &triangle,
-                  float &tmin, float &tmax)
+bool intersection(Ray const &ray, Triangle<3> const &triangle, float &tmin,
+                  float &tmax)
 {
   namespace KokkosExt = Details::KokkosExt;
 
+  using Vector = typename Ray::Vector;
+
   auto dir = ray.direction();
   // normalize the direction vector by its largest component.
   auto kz = findLargestComp(dir);
@@ -314,7 +263,7 @@ bool intersection(Ray const &ray,
   int ky = (kz + 2) % 3;
 
   if (dir[kz] < 0)
-    KokkosExt::swap(kx, ky);
+    Kokkos::kokkos_swap(kx, ky);
 
   Vector s;
 
@@ -323,21 +272,22 @@ bool intersection(Ray const &ray,
   s[1] = dir[ky] * s[2];
 
   // calculate vertices relative to ray origin
-  Vector const oA = makeVector(ray.origin(), triangle.a);
-  Vector const oB = makeVector(ray.origin(), triangle.b);
-  Vector const oC = makeVector(ray.origin(), triangle.c);
+  auto const &o = ray.origin();
+  auto const oA = triangle.a - o;
+  auto const oB = triangle.b - o;
+  auto const oC = triangle.c - o;
 
   // oA, oB, oB need to be normalized, otherwise they
   // will scale with the problem size.
-  float const mag_oA = std::sqrt(dotProduct(oA, oA));
-  float const mag_oB = std::sqrt(dotProduct(oB, oB));
-  float const mag_oC = std::sqrt(dotProduct(oC, oC));
+  auto const mag_oA = oA.norm();
+  auto const mag_oB = oB.norm();
+  auto const mag_oC = oC.norm();
 
   auto mag_bar = 3.0 / (mag_oA + mag_oB + mag_oC);
 
-  Point A;
-  Point B;
-  Point C;
+  Ray::Point A;
+  Ray::Point B;
+  Ray::Point C;
 
   // perform shear and scale of vertices
   // normalized by mag_bar
@@ -413,15 +363,15 @@ bool intersection(Ray const &ray,
   bool bc_intersect = rayEdgeIntersect(B_star, C_star, t_bc);
   if (bc_intersect)
   {
-    tmin = KokkosExt::min(tmin, t_bc);
-    tmax = KokkosExt::max(tmax, t_bc);
+    tmin = Kokkos::min(tmin, t_bc);
+    tmax = Kokkos::max(tmax, t_bc);
   }
   float t_ca = inf;
   bool ca_intersect = rayEdgeIntersect(C_star, A_star, t_ca);
   if (ca_intersect)
   {
-    tmin = KokkosExt::min(tmin, t_ca);
-    tmax = KokkosExt::max(tmax, t_ca);
+    tmin = Kokkos::min(tmin, t_ca);
+    tmax = Kokkos::max(tmax, t_ca);
   }
 
   if (ab_intersect || bc_intersect || ca_intersect)
@@ -441,7 +391,7 @@ bool intersection(Ray const &ray,
       // we want tmin = -1 and tmax = -2, when the
       // ray travels backward
       if (tmin < 0)
-        KokkosExt::swap(tmin, tmax);
+        Kokkos::kokkos_swap(tmin, tmax);
     }
     return true;
   }
@@ -449,9 +399,8 @@ bool intersection(Ray const &ray,
   return false;
 } // namespace Experimental
 
-KOKKOS_INLINE_FUNCTION bool
-intersects(Ray const &ray,
-           ExperimentalHyperGeometry::Triangle<3> const &triangle)
+KOKKOS_INLINE_FUNCTION bool intersects(Ray const &ray,
+                                       Triangle<3> const &triangle)
 {
   float tmin;
   float tmax;
@@ -465,7 +414,7 @@ intersects(Ray const &ray,
 // "smallest distance between a point on the ray and a point in the box"
 // so we can use nearest queries for ray tracing.
 KOKKOS_INLINE_FUNCTION
-float distance(Ray const &ray, Box const &box)
+float distance(Ray const &ray, Box<3> const &box)
 {
   float tmin;
   float tmax;
@@ -522,25 +471,25 @@ KOKKOS_INLINE_FUNCTION bool solveQuadratic(float const a, float const b,
 //     a2 = |d|^2, a1 = 2*(d, o - c), and a0 = |o - c|^2 - r^2.
 // Then, we only need to intersect the solution interval [tmin, tmax] with
 // [0, +inf) for the unidirectional ray.
-KOKKOS_INLINE_FUNCTION bool intersection(Ray const &ray, Sphere const &sphere,
-                                         float &tmin, float &tmax)
+KOKKOS_INLINE_FUNCTION bool
+intersection(Ray const &ray, Sphere<3> const &sphere, float &tmin, float &tmax)
 {
   namespace KokkosExt = ArborX::Details::KokkosExt;
 
   auto const &r = sphere.radius();
 
   // Vector oc = (origin_of_ray - center_of_sphere)
-  Vector const oc = makeVector(sphere.centroid(), ray.origin());
+  auto const oc = ray.origin() - sphere.centroid();
 
   float const a2 = 1.f; // directions are normalized
-  float const a1 = 2.f * dotProduct(ray.direction(), oc);
-  float const a0 = dotProduct(oc, oc) - r * r;
+  float const a1 = 2.f * oc.dot(ray.direction());
+  float const a0 = oc.dot(oc) - r * r;
 
   if (solveQuadratic(a2, a1, a0, tmin, tmax))
   {
     // ensures that tmin <= tmax
     if (tmin > tmax)
-      KokkosExt::swap(tmin, tmax);
+      Kokkos::kokkos_swap(tmin, tmax);
 
     return true;
   }
@@ -562,7 +511,7 @@ overlapDistance(Ray const &ray, Geometry const &geometry, float &length,
   if (intersection(ray, geometry, tmin, tmax) && (tmin <= tmax && tmax >= 0))
   {
     // Overlap [tmin, tmax] with [0, +inf)
-    tmin = KokkosExt::max(0.f, tmin);
+    tmin = Kokkos::max(0.f, tmin);
     // As direction is normalized,
     //   |(o + tmax*d) - (o + tmin*d)| = tmax - tmin
     length = tmax - tmin;
@@ -576,7 +525,7 @@ overlapDistance(Ray const &ray, Geometry const &geometry, float &length,
 }
 
 KOKKOS_INLINE_FUNCTION float overlapDistance(Ray const &ray,
-                                             Sphere const &sphere)
+                                             Sphere<3> const &sphere)
 {
   float distance_to_origin;
   float length;
