@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -9,34 +9,37 @@
  * SPDX-License-Identifier: BSD-3-Clause                                    *
  ****************************************************************************/
 
-#include <ArborX_AccessTraits.hpp>
 #include <ArborX_Box.hpp>
-#include <ArborX_Callbacks.hpp>
 #include <ArborX_Point.hpp>
-#include <ArborX_Predicates.hpp>
+#include <detail/ArborX_AccessTraits.hpp>
+#include <detail/ArborX_Callbacks.hpp>
+#include <detail/ArborX_Predicates.hpp>
 
 // NOTE Let's not bother with __host__ __device__ annotations here
 
 struct NearestPredicates
 {};
 template <>
-struct ArborX::AccessTraits<NearestPredicates, ArborX::PredicatesTag>
+struct ArborX::AccessTraits<NearestPredicates>
 {
   using memory_space = Kokkos::HostSpace;
   static int size(NearestPredicates const &) { return 1; }
-  static auto get(NearestPredicates const &, int) { return nearest(Point{}); }
+  static auto get(NearestPredicates const &, int)
+  {
+    return nearest(Point<3>{});
+  }
 };
 
 struct SpatialPredicates
 {};
 template <>
-struct ArborX::AccessTraits<SpatialPredicates, ArborX::PredicatesTag>
+struct ArborX::AccessTraits<SpatialPredicates>
 {
   using memory_space = Kokkos::HostSpace;
   static int size(SpatialPredicates const &) { return 1; }
   static auto get(SpatialPredicates const &, int)
   {
-    return intersects(Point{});
+    return intersects(Point<3>{});
   }
 };
 
