@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2023 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -14,10 +14,10 @@
 #include "ArborX_EnableDeviceTypes.hpp" // ARBORX_DEVICE_TYPES
 #include "ArborX_EnableViewComparison.hpp"
 #include <ArborX_Dendrogram.hpp>
-#include <ArborX_DetailsKokkosExtViewHelpers.hpp>
-#include <ArborX_DetailsSortUtils.hpp>
-#include <ArborX_DetailsWeightedEdge.hpp>
 #include <ArborX_MinimumSpanningTree.hpp>
+#include <detail/ArborX_WeightedEdge.hpp>
+#include <kokkos_ext/ArborX_KokkosExtViewHelpers.hpp>
+#include <misc/ArborX_SortUtils.hpp>
 
 #include "BoostTest_CUDA_clang_workarounds.hpp"
 #include "boost_ext/TupleComparison.hpp"
@@ -25,7 +25,7 @@
 
 BOOST_AUTO_TEST_SUITE(Dendrogram)
 
-using ArborX::Details::WeightedEdge;
+using ArborX::Experimental::WeightedEdge;
 namespace tt = boost::test_tools;
 
 namespace
@@ -54,7 +54,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(dendrogram_union_find, DeviceType,
                               ARBORX_DEVICE_TYPES)
 {
   using ExecutionSpace = typename DeviceType::execution_space;
-  using ArborX::Details::WeightedEdge;
+  using ArborX::Experimental::WeightedEdge;
 
   ExecutionSpace space;
 
@@ -119,9 +119,10 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(dendrogram_boruvka, DeviceType,
   // binary dendrograms which are all correct. This makes the comparison very
   // hard, and something we want to avoid for now.
   int const n = 3000;
-  auto points = ArborXTest::make_random_cloud<ArborX::Point>(space, n);
+  auto points = ArborXTest::make_random_cloud<ArborX::Point<3>>(space, n);
 
-  MinimumSpanningTree<MemorySpace, BoruvkaMode::HDBSCAN> mst(space, points);
+  ArborX::Experimental::MinimumSpanningTree<MemorySpace, BoruvkaMode::HDBSCAN>
+      mst(space, points);
   ArborX::Experimental::Dendrogram<MemorySpace> dendrogram(space, mst.edges);
 
   // Because the dendrogram in the MST is permuted, we need to reorder it in the
@@ -137,24 +138,22 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(dendrogram_boruvka, DeviceType,
         n - 1);
     Kokkos::parallel_for(
         "ArborX::Testing::compute_weights",
-        Kokkos::RangePolicy<ExecutionSpace>(space, 0, n - 1),
+        Kokkos::RangePolicy(space, 0, n - 1),
         KOKKOS_LAMBDA(int i) { weights(i) = mst.edges(i).weight; });
 
     auto permute = sortObjects(space, weights);
 
-    Kokkos::View<unsigned *, MemorySpace> inv_permute(
+    Kokkos::View<int *, MemorySpace> inv_permute(
         Kokkos::view_alloc(space, Kokkos::WithoutInitializing,
                            "Testing::inv_permute"),
         n - 1);
     Kokkos::parallel_for(
-        "Testing::compute_inv_permute",
-        Kokkos::RangePolicy<ExecutionSpace>(space, 0, n - 1),
+        "Testing::compute_inv_permute", Kokkos::RangePolicy(space, 0, n - 1),
         KOKKOS_LAMBDA(int i) { inv_permute(permute(i)) = i; });
 
     Kokkos::parallel_for(
         "Testing::reorder_mst_dendrogram",
-        Kokkos::RangePolicy<ExecutionSpace>(space, 0, 2 * n - 1),
-        KOKKOS_LAMBDA(int i) {
+        Kokkos::RangePolicy(space, 0, 2 * n - 1), KOKKOS_LAMBDA(int i) {
           if (i < n - 1)
           {
             // Edge
@@ -195,7 +194,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(dendrogram_boruvka_same_weights, DeviceType,
   using MemorySpace = typename DeviceType::memory_space;
 
   using namespace ArborX::Details;
-  using Point = ArborX::ExperimentalHyperGeometry::Point<2, float>;
+  using Point = ArborX::Point<2, float>;
 
   ExecutionSpace space;
 
@@ -211,8 +210,8 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(dendrogram_boruvka_same_weights, DeviceType,
 
   // minpts = 5 is the first value that leads to the test failure with N = 4
   int const minpts = 5;
-  MinimumSpanningTree<MemorySpace, BoruvkaMode::HDBSCAN> mst(space, points,
-                                                             minpts);
+  ArborX::Experimental::MinimumSpanningTree<MemorySpace, BoruvkaMode::HDBSCAN>
+      mst(space, points, minpts);
   ArborX::Experimental::Dendrogram<MemorySpace> dendrogram(space, mst.edges);
 
   // Check that the dendrogram is binary
@@ -220,16 +219,14 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(dendrogram_boruvka_same_weights, DeviceType,
       Kokkos::view_alloc(space, "Testing::count"), 2 * n - 1);
 
   Kokkos::parallel_for(
-      "Testing::count_children",
-      Kokkos::RangePolicy<ExecutionSpace>(space, 0, 2 * n - 1),
+      "Testing::count_children", Kokkos::RangePolicy(space, 0, 2 * n - 1),
       KOKKOS_LAMBDA(int i) {
         Kokkos::atomic_inc(&counts(mst.dendrogram_parents(i)));
       });
 
   int wrong_counts;
   Kokkos::parallel_reduce(
-      "Testing::check_counts",
-      Kokkos::RangePolicy<ExecutionSpace>(space, 0, 2 * n - 1),
+      "Testing::check_counts", Kokkos::RangePolicy(space, 0, 2 * n - 1),
       KOKKOS_LAMBDA(int i, int &update) {
         bool const is_edge = (i < n - 1);
         int const expected_num_children = (is_edge ? 2 : 0);
