@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -9,22 +9,32 @@
  * SPDX-License-Identifier: BSD-3-Clause                                    *
  ****************************************************************************/
 
-#include <ArborX_DetailsAlgorithms.hpp>
-#include <ArborX_DetailsKokkosExtArithmeticTraits.hpp>
-#include <ArborX_HyperBox.hpp>
-#include <ArborX_HyperPoint.hpp>
-#include <ArborX_HyperSphere.hpp>
-#include <ArborX_HyperTriangle.hpp>
+#include <ArborX_Box.hpp>
+#include <ArborX_Ellipsoid.hpp>
+#include <ArborX_Point.hpp>
+#include <ArborX_Segment.hpp>
+#include <ArborX_Sphere.hpp>
+#include <ArborX_Tetrahedron.hpp>
+#include <ArborX_Triangle.hpp>
+#include <algorithms/ArborX_Centroid.hpp>
+#include <algorithms/ArborX_Convert.hpp>
+#include <algorithms/ArborX_Distance.hpp>
+#include <algorithms/ArborX_Equals.hpp>
+#include <algorithms/ArborX_Expand.hpp>
+#include <algorithms/ArborX_Intersects.hpp>
+#include <algorithms/ArborX_Valid.hpp>
+#include <kokkos_ext/ArborX_KokkosExtArithmeticTraits.hpp>
 
 #include <boost/mpl/list.hpp>
 
 #define BOOST_TEST_MODULE Geometry
 #include <boost/test/unit_test.hpp>
 
-using Point = ArborX::ExperimentalHyperGeometry::Point<3>;
-using Box = ArborX::ExperimentalHyperGeometry::Box<3>;
-using Sphere = ArborX::ExperimentalHyperGeometry::Sphere<3>;
-using Triangle = ArborX::ExperimentalHyperGeometry::Triangle<3>;
+using Point = ArborX::Point<3>;
+using Box = ArborX::Box<3>;
+using Sphere = ArborX::Sphere<3>;
+using Triangle = ArborX::Triangle<3>;
+using Tetrahedron = ArborX::ExperimentalHyperGeometry::Tetrahedron<>;
 
 BOOST_AUTO_TEST_CASE(distance_point_point)
 {
@@ -63,6 +73,27 @@ BOOST_AUTO_TEST_CASE(distance_point_sphere)
   BOOST_TEST(distance(Point{{1., 1., 1.}}, sphere) == std::sqrt(3.f) - 1.f);
 }
 
+BOOST_AUTO_TEST_CASE(distance_point_segment)
+{
+  using ArborX::Details::distance;
+
+  using ArborX::Point;
+  using ArborX::Experimental::Segment;
+
+  constexpr Segment segment0{{0.f, 0.f}, {0.f, 0.f}};
+  BOOST_TEST(distance(Point{0.f, 0.f}, segment0) == 0.f);
+  BOOST_TEST(distance(Point{1.f, 0.f}, segment0) == 1.f);
+  BOOST_TEST(distance(Point{-1.f, 0.f}, segment0) == 1.f);
+
+  constexpr Segment segment1{{0.f, 0.f}, {1.f, 1.f}};
+  BOOST_TEST(distance(Point{0.f, 0.f}, segment1) == 0.f);
+  BOOST_TEST(distance(Point{1.f, 1.f}, segment1) == 0.f);
+  BOOST_TEST(distance(Point{0.5f, 0.5f}, segment1) == 0.f);
+  BOOST_TEST(distance(Point{1.0f, 0.f}, segment1) == std::sqrt(0.5f));
+  BOOST_TEST(distance(Point{0.f, -1.f}, segment1) == 1.f);
+  BOOST_TEST(distance(Point{1.5f, 1.f}, segment1) == 0.5f);
+}
+
 BOOST_AUTO_TEST_CASE(distance_point_triangle)
 {
   using ArborX::Details::distance;
@@ -78,9 +109,9 @@ BOOST_AUTO_TEST_CASE(distance_point_triangle)
     1 |    4   | 3
       |        |
   */
-  using Point2 = ArborX::ExperimentalHyperGeometry::Point<2>;
-  constexpr ArborX::ExperimentalHyperGeometry::Triangle<2> triangle2{
-      Point2{-1, 0}, Point2{1, 0}, Point2{0, 1}};
+  using Point2 = ArborX::Point<2>;
+  constexpr ArborX::Triangle triangle2{Point2{-1, 0}, Point2{1, 0},
+                                       Point2{0, 1}};
 
   // vertices
   BOOST_TEST(distance(Point2{-1, 0}, triangle2) == 0);
@@ -105,9 +136,9 @@ BOOST_AUTO_TEST_CASE(distance_point_triangle)
   // outside zone 6
   BOOST_TEST(distance(Point2{1, 1}, triangle2) == std::sqrt(2.f) / 2);
 
-  using Point3 = ArborX::ExperimentalHyperGeometry::Point<3>;
-  constexpr ArborX::ExperimentalHyperGeometry::Triangle<3> triangle3{
-      Point3{1, 0, 0}, Point3{0, 1, 0}, Point3{0, 0, 0}};
+  using Point3 = ArborX::Point<3>;
+  constexpr ArborX::Triangle triangle3{Point3{1, 0, 0}, Point3{0, 1, 0},
+                                       Point3{0, 0, 0}};
 
   // same plane
   BOOST_TEST(distance(Point3{2, 0, 0}, triangle3) == 1);
@@ -123,8 +154,8 @@ BOOST_AUTO_TEST_CASE(distance_point_triangle)
   BOOST_TEST(distance(Point3{0, -1, -1}, triangle3) == std::sqrt(2.f));
   BOOST_TEST(distance(Point3{2, -1, -1}, triangle3) == std::sqrt(3.f));
 
-  constexpr ArborX::ExperimentalHyperGeometry::Triangle<3> triangle3_2{
-      Point3{0, 0, 0}, Point3{0, 1, 0}, Point3{0, 0, 1}};
+  constexpr ArborX::Triangle triangle3_2{Point3{0, 0, 0}, Point3{0, 1, 0},
+                                         Point3{0, 0, 1}};
   BOOST_TEST(distance(Point3{-1, 0, 1}, triangle3_2) == 1);
   BOOST_TEST(distance(Point3{0, -1, -1}, triangle3_2) == std::sqrt(2.f));
   BOOST_TEST(distance(Point3{1, -1, -1}, triangle3_2) == std::sqrt(3.f));
@@ -241,9 +272,8 @@ BOOST_AUTO_TEST_CASE(intersects)
   BOOST_TEST(!intersects(Point{-0.7, -0.8, 0.}, sphere));
 
   // triangle
-  using Point2 = ArborX::ExperimentalHyperGeometry::Point<2>;
-  constexpr ArborX::ExperimentalHyperGeometry::Triangle<2> triangle{
-      {{0, 0}}, {{1, 0}}, {{0, 2}}};
+  using Point2 = ArborX::Point<2>;
+  constexpr ArborX::Triangle<2> triangle{{{0, 0}}, {{1, 0}}, {{0, 2}}};
   BOOST_TEST(intersects(Point2{{0, 0}}, triangle));
   BOOST_TEST(intersects(Point2{{1, 0}}, triangle));
   BOOST_TEST(intersects(Point2{{0, 2}}, triangle));
@@ -255,6 +285,99 @@ BOOST_AUTO_TEST_CASE(intersects)
   BOOST_TEST(!intersects(Point2{{0.5, 1.1}}, triangle));
   BOOST_TEST(!intersects(Point2{{1.1, 0}}, triangle));
   BOOST_TEST(!intersects(Point2{{-0.1, 0}}, triangle));
+
+  // triangle box
+  constexpr ArborX::Triangle<3> triangle3{
+      {{1, 0, 0}}, {{0, 1, 0}}, {{0, 0, 1}}};
+  constexpr Box unit_box{{{0, 0, 0}}, {{1, 1, 1}}};
+  BOOST_TEST(intersects(triangle3, Box{{{0., 0., 0.}}, {{1., 1., 1.}}}));
+  BOOST_TEST(intersects(triangle3, Box{{{.2, .25, .25}}, {{.4, .3, .5}}}));
+  BOOST_TEST(!intersects(triangle3, Box{{{.1, .2, .3}}, {{.2, .3, .4}}}));
+  BOOST_TEST(intersects(triangle3, Box{{{0, 0, 0}}, {{.5, .25, .25}}}));
+  BOOST_TEST(intersects(
+      ArborX::Triangle<3>{{{0, 0, 0}}, {{0, 1, 0}}, {{1, 0, 0}}}, unit_box));
+  BOOST_TEST(intersects(
+      ArborX::Triangle<3>{{{0, 0, 0}}, {{0, 1, 0}}, {{-1, 0, 0}}}, unit_box));
+  BOOST_TEST(intersects(
+      ArborX::Triangle<3>{{{.1, .1, .1}}, {{.1, .9, .1}}, {{.9, .1, .1}}},
+      unit_box));
+
+  // tetrahedron
+  constexpr Tetrahedron tet{{0, 0, 0}, {1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
+  BOOST_TEST(intersects(Point{0, 0, 0}, tet));
+  BOOST_TEST(intersects(Point{1, 0, 0}, tet));
+  BOOST_TEST(intersects(Point{0, 1, 0}, tet));
+  BOOST_TEST(intersects(Point{0, 0, 1}, tet));
+  BOOST_TEST(intersects(Point{0.2, 0.2, 0.1}, tet));
+  BOOST_TEST(!intersects(Point{-0.1, 0, 0}, tet));
+  BOOST_TEST(!intersects(Point{0, -0.1, 0}, tet));
+  BOOST_TEST(!intersects(Point{0, 0, 1.1}, tet));
+  BOOST_TEST(!intersects(Point{0.5, 0.5, 0.5}, tet));
+  BOOST_TEST(!intersects(Point{-0.5, 0.5, 0.5}, tet));
+
+  // segment
+  using Segment2 = ArborX::Experimental::Segment<2>;
+  constexpr Segment2 seg{{1, 1}, {2, 2}};
+  BOOST_TEST(intersects(Segment2{{2, 2}, {3, 3}}, seg));
+  BOOST_TEST(intersects(Segment2{{1.5, 1.5}, {1.7, 1.7}}, seg));
+  BOOST_TEST(intersects(Segment2{{0, 0}, {1, 1}}, seg));
+  BOOST_TEST(intersects(Segment2{{1, 2}, {2, 1}}, seg));
+  BOOST_TEST(intersects(Segment2{{2, 0}, {0, 2}}, seg));
+  BOOST_TEST(intersects(Segment2{{1, 3}, {3, 1}}, seg));
+  BOOST_TEST(!intersects(Segment2{{0, 0}, {0.9, 0.9}}, seg));
+  BOOST_TEST(!intersects(Segment2{{1.1, 1}, {2, 1}}, seg));
+  BOOST_TEST(!intersects(Segment2{{1, 0}, {2, 1}}, seg));
+  BOOST_TEST(!intersects(Segment2{{1, 3}, {3, 1.1}}, seg));
+
+  constexpr ArborX::Box<2> box2{{{0.0, 0.0}}, {{1.0, 1.0}}};
+  BOOST_TEST(intersects(Segment2{{0, 0}, {0, 0}}, box2));
+  BOOST_TEST(intersects(Segment2{{-1, 1}, {1, -1}}, box2));
+  BOOST_TEST(intersects(Segment2{{-1, 0}, {2, 0}}, box2));
+  BOOST_TEST(intersects(Segment2{{-1, 0.5}, {0.5, 0.5}}, box2));
+  BOOST_TEST(intersects(Segment2{{0.5, 0.5}, {0.5, 2}}, box2));
+  BOOST_TEST(intersects(Segment2{{-1, 2}, {2, -1}}, box2));
+  BOOST_TEST(intersects(Segment2{{0.5, 2}, {0.5, -1}}, box2));
+  BOOST_TEST(intersects(Segment2{{0.4, 0.4}, {0.6, 0.6}}, box2));
+  BOOST_TEST(!intersects(Segment2{{0, -1}, {1, -1}}, box2));
+  BOOST_TEST(!intersects(Segment2{{0.5, 1.6}, {2, 0}}, box2));
+  BOOST_TEST(intersects(box2, Segment2{{-1, 2}, {2, -1}}));
+  BOOST_TEST(!intersects(Segment2{{0.5, 1.6}, {2, 0}}, box2));
+
+  // ellipsoid [2x^2 - 3xy + 2y^2 <= 1]
+  using Ellipse = ArborX::Experimental::Ellipsoid<2>;
+  constexpr Ellipse ellipse{{1.f, 1.f}, {{2.f, -1.5f}, {-1.5f, 2.f}}};
+  BOOST_TEST(intersects(ellipse, Point2{1.f, 1.f}));
+  BOOST_TEST(intersects(ellipse, Point2{0.f, 0.f}));
+  BOOST_TEST(!intersects(ellipse, Point2{-0.01f, -0.01f}));
+  BOOST_TEST(intersects(ellipse, Point2{0.f, 0.5f}));
+  BOOST_TEST(!intersects(ellipse, Point2{0.f, 0.6f}));
+  BOOST_TEST(intersects(ellipse, Point2{2.f, 2.f}));
+  BOOST_TEST(!intersects(ellipse, Point2{0.5f, 1.5f}));
+  BOOST_TEST(intersects(ellipse, Point2{1.f, 0.3f}));
+  BOOST_TEST(!intersects(ellipse, Point2{1.f, 0.29f}));
+  BOOST_TEST(intersects(ellipse, Point2{1.f, 1.69f}));
+  BOOST_TEST(intersects(ellipse, Point2{1.f, 1.70f}));
+
+  BOOST_TEST(intersects(ellipse, Segment2{{-1, 1}, {1, -1}}));
+  BOOST_TEST(!intersects(ellipse, Segment2{{-1.1, 1}, {1, -1}}));
+  BOOST_TEST(intersects(ellipse, Segment2{{0, 0}, {0, 1}}));
+  BOOST_TEST(intersects(ellipse, Segment2{{0.5, 0.5}, {1.5, 1.5}}));
+  BOOST_TEST(intersects(ellipse, Segment2{{0.0, 1.9}, {3.0, 1.9}}));
+  BOOST_TEST(!intersects(ellipse, Segment2{{2.1, 0}, {2.1, 3}}));
+
+  using Box2 = ArborX::Box<2>;
+  BOOST_TEST(intersects(ellipse, Box2{{-10, -10}, {10, 10}}));
+  BOOST_TEST(intersects(ellipse, Box2{{0.5, 0.5}, {1.0, 1.0}}));
+  BOOST_TEST(intersects(ellipse, Box2{{-1, -1}, {0, 0}}));
+  BOOST_TEST(intersects(ellipse, Box2{{2, 2}, {3, 3}}));
+  BOOST_TEST(intersects(ellipse, Box2{{-1, -1}, {0, 2}}));
+  BOOST_TEST(intersects(ellipse, Box2{{-1, -1}, {2, 0}}));
+  BOOST_TEST(intersects(ellipse, Box2{{2, 1}, {3, 3}}));
+  BOOST_TEST(intersects(ellipse, Box2{{1, 2}, {3, 3}}));
+  BOOST_TEST(!intersects(ellipse, Box2{{1.5, 0}, {2, 0.5}}));
+  BOOST_TEST(!intersects(ellipse, Box2{{-1, -1}, {-0.1, -0.1}}));
+  BOOST_TEST(!intersects(ellipse, Box2{{0, 1.5}, {0.5, 2}}));
+  BOOST_TEST(!intersects(ellipse, Box2{{2.1, 2.1}, {3, 3}}));
 }
 
 BOOST_AUTO_TEST_CASE(equals)
@@ -309,11 +432,40 @@ BOOST_AUTO_TEST_CASE(expand)
   BOOST_TEST(equals(box, Box{{{-24., -24., -24.}}, {{24., 24., 24.}}}));
   expand(box, Triangle{{{0, 0, 0}}, {{48, 0, 0}}, {{0, 48, 0}}});
   BOOST_TEST(equals(box, Box{{{-24., -24., -24.}}, {{48., 48., 24.}}}));
+
+  // expand box with tetrahedrons
+  box = Box{};
+  expand(box, Tetrahedron{{-1, -2, 3}, {1, 3, 2}, {0, 3, 7}, {-5, 4, 7}});
+  BOOST_TEST(equals(box, Box{{-5, -2, 2}, {1, 4, 7}}));
+  expand(box, Tetrahedron{{-3, -5, 2}, {2, 6, -1}, {3, 2, 3}, {5, 8, -3}});
+  BOOST_TEST(equals(box, Box{{-5, -5, -3}, {5, 8, 7}}));
+
+  // expand box with segments
+  using ArborX::Experimental::Segment;
+  box = Box{};
+  expand(box, Segment{{0.f, 0.f, 0.f}, {1.f, 1.f, 1.f}});
+  BOOST_TEST(equals(box, Box{{0, 0, 0}, {1, 1, 1}}));
+  expand(box, Segment{{-1.f, 3.0f, 0.0f}, {2.f, 1.f, 0.f}});
+  BOOST_TEST(equals(box, Box{{-1, 0, 0}, {2, 3, 1}}));
+}
+
+BOOST_AUTO_TEST_CASE(convert)
+{
+  using ArborX::Point;
+  using ArborX::Details::convert;
+  using ArborX::Details::equals;
+  BOOST_TEST(equals(convert<Point<2, double>>(Point{3.f, 2.f}), Point{3., 2.}));
+  BOOST_TEST(
+      equals(convert<Point<2, float>>(Point{3.f, 2.f}), Point{3.f, 2.f}));
+  BOOST_TEST(
+      !equals(convert<Point<2, float>>(Point{3.f, 2.f}), Point{2.f, 2.f}));
 }
 
 BOOST_AUTO_TEST_CASE(centroid)
 {
+  using ArborX::Details::equals;
   using ArborX::Details::returnCentroid;
+
   Box box{{{-10.0, 0.0, 10.0}}, {{0.0, 10.0, 20.0}}};
   auto center = returnCentroid(box);
   BOOST_TEST(center[0] == -5.0);
@@ -330,6 +482,22 @@ BOOST_AUTO_TEST_CASE(centroid)
   BOOST_TEST(tri3_center[0] == 1);
   BOOST_TEST(tri3_center[1] == 1);
   BOOST_TEST(tri3_center[2] == 0);
+
+  Tetrahedron tet{{{0, 0, -2}}, {{-4, 3, 4}}, {{1, 9, 5}}, {{-1, 0, 1}}};
+  auto tet_center = returnCentroid(tet);
+  BOOST_TEST(tet_center[0] == -1);
+  BOOST_TEST(tet_center[1] == 3);
+  BOOST_TEST(tet_center[2] == 2);
+
+  using ArborX::Experimental::Segment;
+  Segment segment{{-1.f, -1.f}, {3.f, 3.f}};
+  auto seg_center = returnCentroid(segment);
+  BOOST_TEST(equals(seg_center, ArborX::Point{1.f, 1.f}));
+
+  using ArborX::Experimental::Ellipsoid;
+  Ellipsoid ellipse{{1.f, 0.f}, {{2.f, 1.f}, {1.f, 2.f}}};
+  auto ell_center = returnCentroid(ellipse);
+  BOOST_TEST(equals(ell_center, ArborX::Point{1.f, 0.f}));
 }
 
 BOOST_AUTO_TEST_CASE(is_valid)
