@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -9,13 +9,13 @@
  * SPDX-License-Identifier: BSD-3-Clause                                    *
  ****************************************************************************/
 
-#include <ArborX_DetailsMortonCode.hpp>
+#include <detail/ArborX_MortonCode.hpp>
 
 #include <boost/test/unit_test.hpp>
 
 using namespace ArborX::Details;
 
-#include <ArborX_HyperPoint.hpp>
+#include <ArborX_Point.hpp>
 
 BOOST_AUTO_TEST_SUITE(MortonCodes)
 
@@ -50,7 +50,7 @@ BOOST_AUTO_TEST_CASE(expand_bits)
 
 BOOST_AUTO_TEST_CASE(morton_codes)
 {
-  using ArborX::ExperimentalHyperGeometry::Point;
+  using ArborX::Point;
 
   BOOST_TEST(morton32(Point{0.f}) == 0x0u);
   BOOST_TEST(morton32(Point{0.5f}) == 0x40000000u);
