@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2023 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -8,16 +8,16 @@
  *                                                                          *
  * SPDX-License-Identifier: BSD-3-Clause                                    *
  ****************************************************************************/
+#include "ArborXTest_LegacyTree.hpp"
 #include "ArborX_EnableDeviceTypes.hpp" // ARBORX_DEVICE_TYPES
 #include "ArborX_EnableViewComparison.hpp"
-#include <ArborX_DetailsAlgorithms.hpp>
-#include <ArborX_DetailsKokkosExtStdAlgorithms.hpp>
-#include <ArborX_DetailsLegacy.hpp>
-#include <ArborX_DetailsMortonCode.hpp> // expandBits, morton32
-#include <ArborX_DetailsNode.hpp>       // ROPE SENTINEL
-#include <ArborX_DetailsSortUtils.hpp>  // sortObjects
-#include <ArborX_DetailsTreeConstruction.hpp>
-#include <ArborX_IndexableGetter.hpp>
+#include <detail/ArborX_IndexableGetter.hpp>
+#include <detail/ArborX_MortonCode.hpp> // expandBits, morton32
+#include <detail/ArborX_Node.hpp>       // ROPE SENTINEL
+#include <detail/ArborX_SpaceFillingCurves.hpp>
+#include <detail/ArborX_TreeConstruction.hpp>
+#include <kokkos_ext/ArborX_KokkosExtStdAlgorithms.hpp>
+#include <misc/ArborX_SortUtils.hpp> // sortObjects
 
 #include <boost/test/unit_test.hpp>
 
@@ -36,13 +36,13 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(assign_morton_codes, DeviceType,
   // N is the number of Morton grid cells in each dimension for 64-bit Morton
   // codes.
   constexpr unsigned long long N = 1 << 21;
-  std::vector<ArborX::Point> points = {{{0.0, 0.0, 0.0}},
-                                       {{0.25, 0.75, 0.25}},
-                                       {{0.75, 0.25, 0.25}},
-                                       {{0.75, 0.75, 0.25}},
-                                       {{1.33, 2.33, 3.33}},
-                                       {{1.66, 2.66, 3.66}},
-                                       {{(float)N, (float)N, (float)N}}};
+  std::vector<ArborX::Point<3>> points = {{{0.0, 0.0, 0.0}},
+                                          {{0.25, 0.75, 0.25}},
+                                          {{0.75, 0.25, 0.25}},
+                                          {{0.75, 0.75, 0.25}},
+                                          {{1.33, 2.33, 3.33}},
+                                          {{1.66, 2.66, 3.66}},
+                                          {{(float)N, (float)N, (float)N}}};
   int const n = points.size();
   // lower left front corner of the octant the points fall in
   std::vector<std::array<unsigned long long, 3>> anchors = {
@@ -66,28 +66,27 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(assign_morton_codes, DeviceType,
     ref[i] = fun(anchors[i]);
   // using points rather than boxes for convenience here but still have to
   // build the axis-aligned bounding boxes around them
-  Kokkos::View<ArborX::Box *, DeviceType> boxes("boxes", n);
+  Kokkos::View<ArborX::Box<3> *, DeviceType> boxes("boxes", n);
   auto boxes_host = Kokkos::create_mirror_view(boxes);
   for (int i = 0; i < n; ++i)
     ArborX::Details::expand(boxes_host(i), points[i]);
   Kokkos::deep_copy(boxes, boxes_host);
 
   typename DeviceType::execution_space space{};
-  ArborX::Box scene_host;
+  ArborX::Box<3> scene_host;
   ArborX::Details::TreeConstruction::calculateBoundingBoxOfTheScene(
       space, boxes, scene_host);
 
   BOOST_TEST(ArborX::Details::equals(
       scene_host, {{{0.0, 0.0, 0.0}}, {{(float)N, (float)N, (float)N}}}));
 
-  ArborX::Details::LegacyValues<decltype(boxes), ArborX::Box> values{boxes};
-  ArborX::Details::Indexables<decltype(values),
-                              ArborX::Details::DefaultIndexableGetter>
-      indexables{values, ArborX::Details::DefaultIndexableGetter{}};
+  LegacyValues<decltype(boxes), ArborX::Box<3>> values{boxes};
+  ArborX::Details::Indexables indexables{
+      values, ArborX::Experimental::DefaultIndexableGetter{}};
 
   // Test for a bug where missing move ref operator() in DefaultIndexableGetter
   // results in a default initialized indexable used in scene box calucation.
-  scene_host = ArborX::Box{};
+  scene_host = {};
   ArborX::Details::TreeConstruction::calculateBoundingBoxOfTheScene(
       space, indexables, scene_host);
   BOOST_TEST(ArborX::Details::equals(
@@ -95,7 +94,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(assign_morton_codes, DeviceType,
 
   Kokkos::View<unsigned long long *, DeviceType> morton_codes("morton_codes",
                                                               n);
-  ArborX::Details::TreeConstruction::projectOntoSpaceFillingCurve(
+  ArborX::Details::projectOntoSpaceFillingCurve(
       space, boxes, ArborX::Experimental::Morton64(), scene_host, morton_codes);
   auto morton_codes_host = Kokkos::create_mirror_view(morton_codes);
   Kokkos::deep_copy(morton_codes_host, morton_codes);
@@ -172,9 +171,8 @@ void generateHierarchy(Primitives primitives, MortonCodes sorted_morton_codes,
       typename InternalNodes::value_type::bounding_volume_type;
   BoundingVolume bounds;
   ArborX::Details::TreeConstruction::generateHierarchy(
-      space,
-      ArborX::Details::LegacyValues<Primitives, BoundingVolume>{primitives},
-      ArborX::Details::DefaultIndexableGetter{}, permutation_indices,
+      space, LegacyValues<Primitives, BoundingVolume>{primitives},
+      ArborX::Experimental::DefaultIndexableGetter{}, permutation_indices,
       sorted_morton_codes, leaf_nodes, internal_nodes, bounds);
 }
 
