@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -10,6 +10,7 @@
  ****************************************************************************/
 
 #include "ArborX_EnableDeviceTypes.hpp" // ARBORX_DEVICE_TYPES
+#include <ArborXTest_LegacyTree.hpp>
 #include <ArborX_LinearBVH.hpp>
 
 #include <boost/test/unit_test.hpp>
@@ -33,8 +34,12 @@ BOOST_AUTO_TEST_CASE(is_prefixed_with)
 BOOST_AUTO_TEST_CASE_TEMPLATE(bvh_bvh_allocations_prefixed, DeviceType,
                               ARBORX_DEVICE_TYPES)
 {
-  using Tree = ArborX::BVH<typename DeviceType::memory_space>;
   using ExecutionSpace = typename DeviceType::execution_space;
+  using MemorySpace = typename DeviceType::memory_space;
+  using Box = ArborX::Box<3>;
+  using Tree =
+      LegacyTree<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                                 ArborX::PairValueIndex<Box>>>;
 
   Kokkos::Tools::Experimental::set_allocate_data_callback(
       [](Kokkos::Profiling::SpaceHandle /*handle*/, char const *label,
@@ -42,6 +47,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(bvh_bvh_allocations_prefixed, DeviceType,
         std::regex re("^(Testing::"
                       "|ArborX::BVH::"
                       "|ArborX::Sorting::"
+                      "|ArborX::SpaceFillingCurve::"
                       "|Kokkos::SortImpl::BinSortFunctor::"
                       "|Kokkos::Serial::" // unsure what's going on
                       ").*");
@@ -54,20 +60,22 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(bvh_bvh_allocations_prefixed, DeviceType,
   }
 
   { // empty
-    auto tree = make<Tree>(ExecutionSpace{}, {});
+    auto tree = make<Tree, Box>(ExecutionSpace{}, {});
   }
 
   { // one leaf
-    auto tree = make<Tree>(ExecutionSpace{}, {
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                             });
+    auto tree =
+        make<Tree, Box>(ExecutionSpace{}, {
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                          });
   }
 
   { // two leaves
-    auto tree = make<Tree>(ExecutionSpace{}, {
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                             });
+    auto tree =
+        make<Tree, Box>(ExecutionSpace{}, {
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                          });
   }
 
   Kokkos::Tools::Experimental::set_allocate_data_callback(nullptr);
@@ -77,18 +85,24 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(bvh_query_allocations_prefixed, DeviceType,
                               ARBORX_DEVICE_TYPES)
 {
   using ExecutionSpace = typename DeviceType::execution_space;
+  using MemorySpace = typename DeviceType::memory_space;
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
+  using Tree =
+      LegacyTree<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                                 ArborX::PairValueIndex<Box>>>;
 
-  auto tree = make<ArborX::BVH<typename DeviceType::memory_space>>(
-      ExecutionSpace{}, {
-                            {{{0, 0, 0}}, {{1, 1, 1}}},
-                            {{{0, 0, 0}}, {{1, 1, 1}}},
-                        });
+  auto tree = make<Tree, Box>(ExecutionSpace{}, {
+                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
+                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
+                                                });
 
   Kokkos::Tools::Experimental::set_allocate_data_callback(
       [](Kokkos::Profiling::SpaceHandle /*handle*/, char const *label,
          void const * /*ptr*/, uint64_t /*size*/) {
         std::regex re("^(Testing::"
                       "|ArborX::BVH::query::"
+                      "|ArborX::SpaceFillingCurve::"
                       "|ArborX::NearestBufferProvider::"
                       "|ArborX::TreeTraversal::spatial::"
                       "|ArborX::TreeTraversal::nearest::"
@@ -102,14 +116,14 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(bvh_query_allocations_prefixed, DeviceType,
 
   // spatial predicates
   query(ExecutionSpace{}, tree,
-        makeIntersectsBoxQueries<DeviceType>({
+        makeIntersectsQueries<DeviceType, Box>({
             {{{0, 0, 0}}, {{1, 1, 1}}},
             {{{0, 0, 0}}, {{1, 1, 1}}},
         }));
 
   // nearest predicates
   query(ExecutionSpace{}, tree,
-        makeNearestQueries<DeviceType>({
+        makeNearestQueries<DeviceType, Point>({
             {{{0, 0, 0}}, 1},
             {{{0, 0, 0}}, 2},
         }));
@@ -119,8 +133,13 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(bvh_query_allocations_prefixed, DeviceType,
 
 BOOST_AUTO_TEST_CASE_TEMPLATE(kernels_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 {
-  using Tree = ArborX::BVH<typename DeviceType::memory_space>;
   using ExecutionSpace = typename DeviceType::execution_space;
+  using MemorySpace = typename DeviceType::memory_space;
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
+  using Tree =
+      LegacyTree<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                                 ArborX::PairValueIndex<Box>>>;
 
   auto const callback = [](char const *label, uint32_t, uint64_t *) {
     std::regex re("^(ArborX::|Kokkos::).*");
@@ -138,39 +157,41 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(kernels_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
   }
 
   { // empty
-    auto tree = make<Tree>(ExecutionSpace{}, {});
+    auto tree = make<Tree, Box>(ExecutionSpace{}, {});
   }
 
   { // one leaf
-    auto tree = make<Tree>(ExecutionSpace{}, {
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                             });
+    auto tree =
+        make<Tree, Box>(ExecutionSpace{}, {
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                          });
   }
 
   { // two leaves
-    auto tree = make<Tree>(ExecutionSpace{}, {
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                             });
+    auto tree =
+        make<Tree, Box>(ExecutionSpace{}, {
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                          });
   }
 
   // BVH::query
 
-  auto tree = make<Tree>(ExecutionSpace{}, {
-                                               {{{0, 0, 0}}, {{1, 1, 1}}},
-                                               {{{0, 0, 0}}, {{1, 1, 1}}},
-                                           });
+  auto tree = make<Tree, Box>(ExecutionSpace{}, {
+                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
+                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
+                                                });
 
   // spatial predicates
   query(ExecutionSpace{}, tree,
-        makeIntersectsBoxQueries<DeviceType>({
+        makeIntersectsQueries<DeviceType, Box>({
             {{{0, 0, 0}}, {{1, 1, 1}}},
             {{{0, 0, 0}}, {{1, 1, 1}}},
         }));
 
   // nearest predicates
   query(ExecutionSpace{}, tree,
-        makeNearestQueries<DeviceType>({
+        makeNearestQueries<DeviceType, Point>({
             {{{0, 0, 0}}, 1},
             {{{0, 0, 0}}, 2},
         }));
@@ -182,8 +203,13 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(kernels_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 
 BOOST_AUTO_TEST_CASE_TEMPLATE(regions_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 {
-  using Tree = ArborX::BVH<typename DeviceType::memory_space>;
   using ExecutionSpace = typename DeviceType::execution_space;
+  using MemorySpace = typename DeviceType::memory_space;
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
+  using Tree =
+      LegacyTree<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                                 ArborX::PairValueIndex<Box>>>;
 
   Kokkos::Tools::Experimental::set_push_region_callback([](char const *label) {
     std::regex re("^(ArborX::|Kokkos::).*");
@@ -198,39 +224,41 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(regions_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
   }
 
   { // empty
-    auto tree = make<Tree>(ExecutionSpace{}, {});
+    auto tree = make<Tree, Box>(ExecutionSpace{}, {});
   }
 
   { // one leaf
-    auto tree = make<Tree>(ExecutionSpace{}, {
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                             });
+    auto tree =
+        make<Tree, Box>(ExecutionSpace{}, {
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                          });
   }
 
   { // two leaves
-    auto tree = make<Tree>(ExecutionSpace{}, {
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                 {{{0, 0, 0}}, {{1, 1, 1}}},
-                                             });
+    auto tree =
+        make<Tree, Box>(ExecutionSpace{}, {
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                              {{{0, 0, 0}}, {{1, 1, 1}}},
+                                          });
   }
 
   // BVH::query
 
-  auto tree = make<Tree>(ExecutionSpace{}, {
-                                               {{{0, 0, 0}}, {{1, 1, 1}}},
-                                               {{{0, 0, 0}}, {{1, 1, 1}}},
-                                           });
+  auto tree = make<Tree, Box>(ExecutionSpace{}, {
+                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
+                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
+                                                });
 
   // spatial predicates
   query(ExecutionSpace{}, tree,
-        makeIntersectsBoxQueries<DeviceType>({
+        makeIntersectsQueries<DeviceType, Box>({
             {{{0, 0, 0}}, {{1, 1, 1}}},
             {{{0, 0, 0}}, {{1, 1, 1}}},
         }));
 
   // nearest predicates
   query(ExecutionSpace{}, tree,
-        makeNearestQueries<DeviceType>({
+        makeNearestQueries<DeviceType, Point>({
             {{{0, 0, 0}}, 1},
             {{{0, 0, 0}}, 2},
         }));
