@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -10,6 +10,7 @@
  ****************************************************************************/
 
 #include "ArborX_EnableDeviceTypes.hpp" // ARBORX_DEVICE_TYPES
+#include <ArborX_Box.hpp>
 #include <ArborX_DistributedTree.hpp>
 
 #include <boost/test/unit_test.hpp>
@@ -26,11 +27,14 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
     distributed_search_tree_distributed_search_tree_allocations_prefixed,
     DeviceType, ARBORX_DEVICE_TYPES)
 {
-  auto tree = makeDistributedTree<DeviceType>(MPI_COMM_WORLD,
-                                              {
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                              });
+  using ExecutionSpace = typename DeviceType::execution_space;
+
+  auto tree = makeDistributedTree<DeviceType, ArborX::Box<3>>(
+      MPI_COMM_WORLD, ExecutionSpace{},
+      {
+          {{{0, 0, 0}}, {{1, 1, 1}}},
+          {{{0, 0, 0}}, {{1, 1, 1}}},
+      });
 
   Kokkos::Tools::Experimental::set_allocate_data_callback(
       [](Kokkos::Profiling::SpaceHandle /*handle*/, char const *label,
@@ -38,6 +42,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
         std::regex re("^(Testing::"
                       "|ArborX::DistributedTree::"
                       "|ArborX::BVH::"
+                      "|ArborX::SpaceFillingCurve::"
                       "|ArborX::Sorting::"
                       ").*");
         BOOST_TEST(std::regex_match(label, re),
@@ -45,10 +50,11 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
       });
 
   { // one leaf per process
-    auto tree = makeDistributedTree<DeviceType>(MPI_COMM_WORLD,
-                                                {
-                                                    {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                });
+    auto tree = makeDistributedTree<DeviceType, ArborX::Box<3>>(
+        MPI_COMM_WORLD, ExecutionSpace{},
+        {
+            {{{0, 0, 0}}, {{1, 1, 1}}},
+        });
   }
 
   Kokkos::Tools::Experimental::set_allocate_data_callback(nullptr);
@@ -59,18 +65,22 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
     ARBORX_DEVICE_TYPES)
 {
   using ExecutionSpace = typename DeviceType::execution_space;
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
 
-  auto tree = makeDistributedTree<DeviceType>(MPI_COMM_WORLD,
-                                              {
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                              });
+  auto tree =
+      makeDistributedTree<DeviceType, Box>(MPI_COMM_WORLD, ExecutionSpace{},
+                                           {
+                                               {{{0, 0, 0}}, {{1, 1, 1}}},
+                                               {{{0, 0, 0}}, {{1, 1, 1}}},
+                                           });
 
   Kokkos::Tools::Experimental::set_allocate_data_callback(
       [](Kokkos::Profiling::SpaceHandle /*handle*/, char const *label,
          void const * /*ptr*/, uint64_t /*size*/) {
         std::regex re("^(Testing::"
                       "|ArborX::DistributedTree::query::"
+                      "|ArborX::SpaceFillingCurve::"
                       "|ArborX::Distributor::"
                       "|ArborX::BVH::query::"
                       "|ArborX::NearestBufferProvider::"
@@ -86,14 +96,14 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
 
   // spatial predicates
   query(ExecutionSpace{}, tree,
-        makeIntersectsBoxQueries<DeviceType>({
+        makeIntersectsQueries<DeviceType, Box>({
             {{{0, 0, 0}}, {{1, 1, 1}}},
             {{{0, 0, 0}}, {{1, 1, 1}}},
         }));
 
   // nearest predicates
   query(ExecutionSpace{}, tree,
-        makeNearestQueries<DeviceType>({
+        makeNearestQueries<DeviceType, Point>({
             {{{0, 0, 0}}, 1},
             {{{0, 0, 0}}, 2},
         }));
@@ -104,6 +114,8 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
 BOOST_AUTO_TEST_CASE_TEMPLATE(kernels_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 {
   using ExecutionSpace = typename DeviceType::execution_space;
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
 
   auto const callback = [](char const *label, uint32_t, uint64_t *) {
     std::regex re("^(ArborX::|Kokkos::).*");
@@ -116,22 +128,23 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(kernels_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 
   // DistributedTree::query
 
-  auto tree = makeDistributedTree<DeviceType>(MPI_COMM_WORLD,
-                                              {
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                              });
+  auto tree =
+      makeDistributedTree<DeviceType, Box>(MPI_COMM_WORLD, ExecutionSpace{},
+                                           {
+                                               {{{0, 0, 0}}, {{1, 1, 1}}},
+                                               {{{0, 0, 0}}, {{1, 1, 1}}},
+                                           });
 
   // spatial predicates
   query(ExecutionSpace{}, tree,
-        makeIntersectsBoxQueries<DeviceType>({
+        makeIntersectsQueries<DeviceType, Box>({
             {{{0, 0, 0}}, {{1, 1, 1}}},
             {{{0, 0, 0}}, {{1, 1, 1}}},
         }));
 
   // nearest predicates
   query(ExecutionSpace{}, tree,
-        makeNearestQueries<DeviceType>({
+        makeNearestQueries<DeviceType, Point>({
             {{{0, 0, 0}}, 1},
             {{{0, 0, 0}}, 2},
         }));
@@ -144,6 +157,8 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(kernels_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 BOOST_AUTO_TEST_CASE_TEMPLATE(regions_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
 {
   using ExecutionSpace = typename DeviceType::execution_space;
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
 
   Kokkos::Tools::Experimental::set_push_region_callback([](char const *label) {
     std::regex re("^(ArborX::|Kokkos::).*");
@@ -154,27 +169,29 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(regions_prefixed, DeviceType, ARBORX_DEVICE_TYPES)
   // DistributedTree::DistriibutedSearchTree
 
   { // empty
-    auto tree = makeDistributedTree<DeviceType>(MPI_COMM_WORLD, {});
+    auto tree = makeDistributedTree<DeviceType, Box>(MPI_COMM_WORLD,
+                                                     ExecutionSpace{}, {});
   }
 
   // DistributedTree::query
 
-  auto tree = makeDistributedTree<DeviceType>(MPI_COMM_WORLD,
-                                              {
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                                  {{{0, 0, 0}}, {{1, 1, 1}}},
-                                              });
+  auto tree =
+      makeDistributedTree<DeviceType, Box>(MPI_COMM_WORLD, ExecutionSpace{},
+                                           {
+                                               {{{0, 0, 0}}, {{1, 1, 1}}},
+                                               {{{0, 0, 0}}, {{1, 1, 1}}},
+                                           });
 
   // spatial predicates
   query(ExecutionSpace{}, tree,
-        makeIntersectsBoxQueries<DeviceType>({
+        makeIntersectsQueries<DeviceType, Box>({
             {{{0, 0, 0}}, {{1, 1, 1}}},
             {{{0, 0, 0}}, {{1, 1, 1}}},
         }));
 
   // nearest predicates
   query(ExecutionSpace{}, tree,
-        makeNearestQueries<DeviceType>({
+        makeNearestQueries<DeviceType, Point>({
             {{{0, 0, 0}}, 1},
             {{{0, 0, 0}}, 2},
         }));
