@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -24,7 +24,7 @@
 
 namespace Test
 {
-struct UndirectedEdge : ArborX::Details::WeightedEdge
+struct UndirectedEdge : ArborX::Experimental::WeightedEdge
 {
 private:
   friend bool operator==(UndirectedEdge const &lhs, UndirectedEdge const &rhs)
@@ -33,7 +33,7 @@ private:
             (lhs.source == rhs.target && lhs.target == rhs.source));
   }
   friend std::ostream &operator<<(std::ostream &os,
-                                  ArborX::Details::WeightedEdge const &e)
+                                  ArborX::Experimental::WeightedEdge const &e)
   {
     os << e.source << " -> " << e.target << " [weight=" << e.weight << "]";
     return os;
@@ -45,15 +45,15 @@ auto parsePointsFromCSVFile(std::string const &filename)
   std::fstream fin(filename, std::ios::in);
   using Tokenizer = boost::tokenizer<boost::escaped_list_separator<char>>;
   std::string line;
-  std::vector<ArborX::Point> points;
+  std::vector<ArborX::Point<3>> points;
   assert(fin.is_open());
   while (std::getline(fin, line))
   {
     Tokenizer tok(line);
     auto first = tok.begin();
     auto const last = tok.end();
-    points.emplace_back(std::stof(*first++), std::stof(*first++),
-                        std::stof(*first++));
+    points.push_back( // NOLINT(modernize-use-emplace)
+        {std::stof(*first++), std::stof(*first++), std::stof(*first++)});
     assert(first == last);
   }
   return points;
@@ -93,7 +93,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(minimum_spanning_tree_golden_test, DeviceType,
   auto edges_ref = Test::parseEdgesFromCSVFile("mst_golden_test_edges.csv");
   std::sort(edges_ref.data(), edges_ref.data() + edges_ref.size());
 
-  using ArborX::Details::MinimumSpanningTree;
+  using ArborX::Experimental::MinimumSpanningTree;
   auto edges = Kokkos::create_mirror_view_and_copy(
       Kokkos::HostSpace{},
       MinimumSpanningTree<MemorySpace>(exec_space, points).edges);
