@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2023 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -19,9 +19,9 @@
 #include "ArborXTest_StdVectorToKokkosView.hpp"
 #include "ArborX_EnableDeviceTypes.hpp" // ARBORX_DEVICE_TYPES
 #include "ArborX_EnableViewComparison.hpp"
-#include <ArborX_DetailsExpandHalfToFull.hpp>
-#include <ArborX_NeighborList.hpp>
 #include <ArborX_Sphere.hpp>
+#include <detail/ArborX_ExpandHalfToFull.hpp>
+#include <detail/ArborX_NeighborList.hpp>
 
 #include <Kokkos_Random.hpp>
 
@@ -34,10 +34,12 @@ using ArborXTest::toView;
 
 struct Filter
 {
-  template <class Predicate, class OutputFunctor>
-  KOKKOS_FUNCTION void operator()(Predicate const &predicate, int i,
+  template <class Predicate, typename Value, class OutputFunctor>
+  KOKKOS_FUNCTION void operator()(Predicate const &predicate,
+                                  Value const &value,
                                   OutputFunctor const &out) const
   {
+    int const i = value.index;
     int const j = getData(predicate);
     if (i < j)
     {
@@ -52,7 +54,8 @@ auto compute_reference(ExecutionSpace const &exec_space, Points const &points,
 {
   Kokkos::View<int *, ExecutionSpace> offsets("Test::offsets", 0);
   Kokkos::View<int *, ExecutionSpace> indices("Test::indices", 0);
-  ArborX::BoundingVolumeHierarchy<MemorySpace> bvh(exec_space, points);
+  ArborX::BoundingVolumeHierarchy bvh(
+      exec_space, ArborX::Experimental::attach_indices(points));
   auto predicates = ArborX::Experimental::attach_indices<int>(
       ArborX::Experimental::make_intersects(points, radius));
   bvh.query(exec_space, predicates, Filter{}, indices, offsets);
@@ -108,10 +111,10 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(find_neighbor_list_degenerate, DeviceType,
   ExecutionSpace exec_space;
 
   auto no_point = ArborXTest::toView<ExecutionSpace>(
-      std::vector<ArborX::Point>{}, "Test::no_point");
+      std::vector<ArborX::Point<3>>{}, "Test::no_point");
 
   auto single_point = ArborXTest::toView<ExecutionSpace>(
-      std::vector<ArborX::Point>{{0.f, 0.f, 0.f}}, "Test::single_point");
+      std::vector<ArborX::Point<3>>{{0.f, 0.f, 0.f}}, "Test::single_point");
 
   constexpr auto radius =
       ArborX::Details::KokkosExt::ArithmeticTraits::infinity<float>::value;
@@ -130,7 +133,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(find_neighbor_list, DeviceType,
   ExecutionSpace exec_space;
 
   auto points = ArborXTest::toView<ExecutionSpace>(
-      std::vector<ArborX::Point>{
+      std::vector<ArborX::Point<3>>{
           {0.f, 0.f, 0.f},
           {1.f, 1.f, 1.f},
           {2.f, 2.f, 2.f},
@@ -163,7 +166,8 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(
   using ExecutionSpace = typename DeviceType::execution_space;
   ExecutionSpace exec_space;
 
-  auto points = ArborXTest::make_random_cloud<ArborX::Point>(exec_space, 100);
+  auto points =
+      ArborXTest::make_random_cloud<ArborX::Point<3>>(exec_space, 100);
   auto radius = .3f;
 
   BOOST_TEST(
