@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2023 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -23,65 +23,76 @@ BOOST_AUTO_TEST_SUITE(Callbacks)
 
 namespace tt = boost::test_tools;
 
-template <typename DeviceType>
+template <typename Points>
 struct CustomInlineCallback
 {
-  Kokkos::View<ArborX::Point *, DeviceType> points;
-  ArborX::Point const origin = {{0., 0., 0.}};
+  static_assert(Kokkos::is_view_v<Points> && Points::rank() == 1);
+  using Point = typename Points::value_type;
+
+  Points points;
+  Point const origin = {{0., 0., 0.}};
+
   template <typename Query, typename Insert>
   KOKKOS_FUNCTION void operator()(Query const &, int index,
                                   Insert const &insert) const
   {
-    float const distance_to_origin =
+    auto const distance_to_origin =
         ArborX::Details::distance(points(index), origin);
     insert({index, distance_to_origin});
   }
 };
 
-template <typename DeviceType>
+template <typename Points>
 struct CustomPostCallback
 {
+  static_assert(Kokkos::is_view_v<Points> && Points::rank() == 1);
+  using Point = typename Points::value_type;
   using tag = ArborX::Details::PostCallbackTag;
-  Kokkos::View<ArborX::Point *, DeviceType> points;
-  ArborX::Point const origin = {{0., 0., 0.}};
+
+  Points points;
+  Point const origin = {{0., 0., 0.}};
   template <typename Predicates, typename InOutView, typename InView,
             typename OutView>
   void operator()(Predicates const &, InOutView &offset, InView in,
                   OutView &out) const
   {
-    using ExecutionSpace = typename DeviceType::execution_space;
+    using ExecutionSpace = typename Points::execution_space;
+
     using ArborX::Details::distance;
     auto const n = offset.extent(0) - 1;
     Kokkos::realloc(out, in.extent(0));
     Kokkos::parallel_for(
         Kokkos::RangePolicy<ExecutionSpace>(0, n), KOKKOS_CLASS_LAMBDA(int i) {
           for (int j = offset(i); j < offset(i + 1); ++j)
-          {
-            out(j) = {in(j), (float)distance(points(in(j)), origin)};
-          }
+            out(j) = {in(j), distance(points(in(j)), origin)};
         });
   }
 };
 
-template <typename View>
-std::vector<Kokkos::pair<int, float>> initialize_values(View const &points,
-                                                        float const delta)
+template <typename Points>
+std::vector<Kokkos::pair<int, ArborX::GeometryTraits::coordinate_type_t<
+                                  typename Points::value_type>>>
+initialize_values(Points const &points, float const delta)
 {
-  using MemorySpace = typename View::memory_space;
-  using ExecutionSpace = typename View::execution_space;
+  using MemorySpace = typename Points::memory_space;
+  using ExecutionSpace = typename Points::execution_space;
+  using Coordinate =
+      ArborX::GeometryTraits::coordinate_type_t<typename Points::value_type>;
+  using PairIndexDistance = Kokkos::pair<int, Coordinate>;
+
   int const n = points.size();
-  Kokkos::View<Kokkos::pair<int, float> *, MemorySpace> values_device(
-      "values_device", n);
+  Kokkos::View<PairIndexDistance *, MemorySpace> values_device("values_device",
+                                                               n);
   Kokkos::parallel_for(
       Kokkos::RangePolicy<ExecutionSpace>(0, n), KOKKOS_LAMBDA(int i) {
-        ArborX::Point const origin = {{0., 0., 0.}};
+        ArborX::Point const origin{(Coordinate)0, (Coordinate)0, (Coordinate)0};
         values_device(i) = {
             i, delta + ArborX::Details::distance(points(i), origin)};
       });
-  std::vector<Kokkos::pair<int, float>> values(n);
-  Kokkos::deep_copy(Kokkos::View<Kokkos::pair<int, float> *, Kokkos::HostSpace>(
-                        values.data(), n),
-                    values_device);
+  std::vector<PairIndexDistance> values(n);
+  Kokkos::deep_copy(
+      Kokkos::View<PairIndexDistance *, Kokkos::HostSpace>(values.data(), n),
+      values_device);
   return values;
 }
 
@@ -92,12 +103,17 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_spatial_predicate, TreeTypeTraits,
   using ExecutionSpace = typename TreeTypeTraits::execution_space;
   using DeviceType = typename TreeTypeTraits::device_type;
 
+  using Coordinate = ArborX::GeometryTraits::coordinate_type_t<
+      typename Tree::bounding_volume_type>;
+  using Point = ArborX::Point<3, Coordinate>;
+  using Box = ArborX::Box<3, Coordinate>;
+
   int const n = 10;
-  Kokkos::View<ArborX::Point *, DeviceType> points(
+  Kokkos::View<Point *, DeviceType> points(
       Kokkos::view_alloc(Kokkos::WithoutInitializing, "points"), n);
   Kokkos::parallel_for(
       Kokkos::RangePolicy<ExecutionSpace>(0, n), KOKKOS_LAMBDA(int i) {
-        points(i) = {{(double)i, (double)i, (double)i}};
+        points(i) = {{(Coordinate)i, (Coordinate)i, (Coordinate)i}};
       });
 
   auto values = initialize_values(points, /*delta*/ 0.f);
@@ -105,18 +121,19 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_spatial_predicate, TreeTypeTraits,
 
   Tree const tree(ExecutionSpace{}, points);
 
-  ARBORX_TEST_QUERY_TREE_CALLBACK(ExecutionSpace{}, tree,
-                                  makeIntersectsBoxQueries<DeviceType>({
-                                      static_cast<ArborX::Box>(tree.bounds()),
-                                  }),
-                                  CustomInlineCallback<DeviceType>{points},
-                                  make_compressed_storage(offsets, values));
+  ARBORX_TEST_QUERY_TREE_CALLBACK(
+      ExecutionSpace{}, tree,
+      (makeIntersectsQueries<DeviceType, Box>({
+          static_cast<Box>(tree.bounds()),
+      })),
+      CustomInlineCallback<decltype(points)>{points},
+      make_compressed_storage(offsets, values));
 
   ARBORX_TEST_QUERY_TREE_CALLBACK(ExecutionSpace{}, tree,
-                                  makeIntersectsBoxQueries<DeviceType>({
-                                      static_cast<ArborX::Box>(tree.bounds()),
-                                  }),
-                                  CustomPostCallback<DeviceType>{points},
+                                  (makeIntersectsQueries<DeviceType, Box>({
+                                      static_cast<Box>(tree.bounds()),
+                                  })),
+                                  CustomPostCallback<decltype(points)>{points},
                                   make_compressed_storage(offsets, values));
 }
 
@@ -127,33 +144,40 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_nearest_predicate, TreeTypeTraits,
   using Tree = typename TreeTypeTraits::type;
   using ExecutionSpace = typename TreeTypeTraits::execution_space;
   using DeviceType = typename TreeTypeTraits::device_type;
+  using Coordinate = ArborX::GeometryTraits::coordinate_type_t<
+      typename Tree::bounding_volume_type>;
+  using Point = ArborX::Point<3, Coordinate>;
 
   int const n = 10;
-  Kokkos::View<ArborX::Point *, DeviceType> points(
+  Kokkos::View<Point *, DeviceType> points(
       Kokkos::view_alloc(Kokkos::WithoutInitializing, "points"), n);
   Kokkos::parallel_for(
       Kokkos::RangePolicy<ExecutionSpace>(0, n), KOKKOS_LAMBDA(int i) {
-        points(i) = {{(double)i, (double)i, (double)i}};
+        points(i) = {{(Coordinate)i, (Coordinate)i, (Coordinate)i}};
       });
-  ArborX::Point const origin = {{0., 0., 0.}};
+#ifdef KOKKOS_COMPILER_NVCC
+  [[maybe_unused]]
+#endif
+  Point const origin = {{0., 0., 0.}};
 
   auto values = initialize_values(points, /*delta*/ 0.f);
   std::vector<int> offsets = {0, n};
 
   Tree const tree(ExecutionSpace{}, points);
 
-  ARBORX_TEST_QUERY_TREE_CALLBACK(ExecutionSpace{}, tree,
-                                  makeNearestQueries<DeviceType>({
-                                      {origin, n},
-                                  }),
-                                  CustomInlineCallback<DeviceType>{points},
-                                  make_compressed_storage(offsets, values));
+  ARBORX_TEST_QUERY_TREE_CALLBACK(
+      ExecutionSpace{}, tree,
+      (makeNearestQueries<DeviceType, Point>({
+          {origin, n},
+      })),
+      CustomInlineCallback<decltype(points)>{points},
+      make_compressed_storage(offsets, values));
 
   ARBORX_TEST_QUERY_TREE_CALLBACK(ExecutionSpace{}, tree,
-                                  makeNearestQueries<DeviceType>({
+                                  (makeNearestQueries<DeviceType, Point>({
                                       {origin, n},
-                                  }),
-                                  CustomPostCallback<DeviceType>{points},
+                                  })),
+                                  CustomPostCallback<decltype(points)>{points},
                                   make_compressed_storage(offsets, values));
 }
 #endif
@@ -184,22 +208,27 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_early_exit, TreeTypeTraits,
   using Tree = typename TreeTypeTraits::type;
   using ExecutionSpace = typename TreeTypeTraits::execution_space;
   using DeviceType = typename TreeTypeTraits::device_type;
+  using BoundingVolume = typename Tree::bounding_volume_type;
+  constexpr int DIM = ArborX::GeometryTraits::dimension_v<BoundingVolume>;
+  using Coordinate = ArborX::GeometryTraits::coordinate_type_t<BoundingVolume>;
+  using Box = ArborX::Box<DIM, Coordinate>;
 
   auto const tree =
-      make<Tree>(ExecutionSpace{}, {
-                                       {{{0., 0., 0.}}, {{0., 0., 0.}}},
-                                       {{{1., 1., 1.}}, {{1., 1., 1.}}},
-                                       {{{2., 2., 2.}}, {{2., 2., 2.}}},
-                                       {{{3., 3., 3.}}, {{3., 3., 3.}}},
-                                   });
+      make<Tree, Box>(ExecutionSpace{}, {
+                                            {{{0., 0., 0.}}, {{0., 0., 0.}}},
+                                            {{{1., 1., 1.}}, {{1., 1., 1.}}},
+                                            {{{2., 2., 2.}}, {{2., 2., 2.}}},
+                                            {{{3., 3., 3.}}, {{3., 3., 3.}}},
+                                        });
 
   Kokkos::View<int *, DeviceType> counts("counts", 4);
 
   std::vector<int> counts_ref(4);
   std::iota(counts_ref.begin(), counts_ref.end(), 1);
 
-  auto b = static_cast<ArborX::Box>(tree.bounds());
-  auto predicates = makeIntersectsBoxWithAttachmentQueries<DeviceType, int>(
+  Box b;
+  ArborX::Details::expand(b, tree.bounds());
+  auto predicates = makeIntersectsWithAttachmentQueries<DeviceType, Box, int>(
       {b, b, b, b}, {0, 1, 2, 3});
 
   tree.query(ExecutionSpace{}, predicates,
@@ -212,34 +241,41 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_early_exit, TreeTypeTraits,
 }
 #endif
 
-template <typename DeviceType>
+template <typename Points>
 struct CustomInlineCallbackWithAttachment
 {
-  Kokkos::View<ArborX::Point *, DeviceType> points;
-  ArborX::Point const origin = {{0., 0., 0.}};
+  using Point = typename Points::value_type;
+
+  Points points;
+  Point const origin = {{0., 0., 0.}};
+
   template <typename Query, typename Insert>
   KOKKOS_FUNCTION void operator()(Query const &query, int index,
                                   Insert const &insert) const
   {
-    float const distance_to_origin =
+    auto const distance_to_origin =
         ArborX::Details::distance(points(index), origin);
 
     auto data = ArborX::getData(query);
     insert({index, data + distance_to_origin});
   }
 };
-template <typename DeviceType>
+template <typename Points>
 struct CustomPostCallbackWithAttachment
 {
   using tag = ArborX::Details::PostCallbackTag;
-  Kokkos::View<ArborX::Point *, DeviceType> points;
-  ArborX::Point const origin = {{0., 0., 0.}};
+
+  using Point = typename Points::value_type;
+
+  Points points;
+  Point const origin = {{0., 0., 0.}};
+
   template <typename Predicates, typename InOutView, typename InView,
             typename OutView>
   void operator()(Predicates const &queries, InOutView &offset, InView in,
                   OutView &out) const
   {
-    using ExecutionSpace = typename DeviceType::execution_space;
+    using ExecutionSpace = typename Points::execution_space;
     using ArborX::Details::distance;
     auto const n = offset.extent(0) - 1;
     Kokkos::realloc(out, in.extent(0));
@@ -249,7 +285,7 @@ struct CustomPostCallbackWithAttachment
           auto data = data_2[1];
           for (int j = offset(i); j < offset(i + 1); ++j)
           {
-            out(j) = {in(j), data + (float)distance(points(in(j)), origin)};
+            out(j) = {in(j), data + distance(points(in(j)), origin)};
           }
         });
   }
@@ -261,34 +297,41 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_with_attachment_spatial_predicate,
   using Tree = typename TreeTypeTraits::type;
   using ExecutionSpace = typename TreeTypeTraits::execution_space;
   using DeviceType = typename TreeTypeTraits::device_type;
+  using BoundingVolume = typename Tree::bounding_volume_type;
+  using Coordinate = ArborX::GeometryTraits::coordinate_type_t<BoundingVolume>;
+  using Point = ArborX::Point<3, Coordinate>;
+  using Box = ArborX::Box<3, Coordinate>;
 
   int const n = 10;
-  Kokkos::View<ArborX::Point *, DeviceType> points(
+  Kokkos::View<Point *, DeviceType> points(
       Kokkos::view_alloc(Kokkos::WithoutInitializing, "points"), n);
   Kokkos::parallel_for(
       Kokkos::RangePolicy<ExecutionSpace>(0, n), KOKKOS_LAMBDA(int i) {
-        points(i) = {{(double)i, (double)i, (double)i}};
+        points(i) = {{(Coordinate)i, (Coordinate)i, (Coordinate)i}};
       });
-  float const delta = 5.f;
+  Coordinate const delta = 5.f;
 
   auto values = initialize_values(points, delta);
   std::vector<int> offsets = {0, n};
 
   Tree const tree(ExecutionSpace{}, points);
 
+  Box bounds;
+  ArborX::Details::expand(bounds, tree.bounds());
+
   ARBORX_TEST_QUERY_TREE_CALLBACK(
       ExecutionSpace{}, tree,
-      (makeIntersectsBoxWithAttachmentQueries<DeviceType, float>(
-          {static_cast<ArborX::Box>(tree.bounds())}, {delta})),
-      CustomInlineCallbackWithAttachment<DeviceType>{points},
+      (makeIntersectsWithAttachmentQueries<DeviceType, Box, Coordinate>(
+          {bounds}, {delta})),
+      CustomInlineCallbackWithAttachment<decltype(points)>{points},
       make_compressed_storage(offsets, values));
 
   ARBORX_TEST_QUERY_TREE_CALLBACK(
       ExecutionSpace{}, tree,
-      (makeIntersectsBoxWithAttachmentQueries<DeviceType,
-                                              Kokkos::Array<float, 2>>(
-          {static_cast<ArborX::Box>(tree.bounds())}, {{0., delta}})),
-      CustomPostCallbackWithAttachment<DeviceType>{points},
+      (makeIntersectsWithAttachmentQueries<DeviceType, Box,
+                                           Kokkos::Array<Coordinate, 2>>(
+          {bounds}, {{0., delta}})),
+      CustomPostCallbackWithAttachment<decltype(points)>{points},
       make_compressed_storage(offsets, values));
 }
 
@@ -299,16 +342,22 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_with_attachment_nearest_predicate,
   using Tree = typename TreeTypeTraits::type;
   using ExecutionSpace = typename TreeTypeTraits::execution_space;
   using DeviceType = typename TreeTypeTraits::device_type;
+  using BoundingVolume = typename Tree::bounding_volume_type;
+  using Coordinate = ArborX::GeometryTraits::coordinate_type_t<BoundingVolume>;
+  using Point = ArborX::Point<3, Coordinate>;
 
   int const n = 10;
-  Kokkos::View<ArborX::Point *, DeviceType> points(
+  Kokkos::View<Point *, DeviceType> points(
       Kokkos::view_alloc(Kokkos::WithoutInitializing, "points"), n);
   Kokkos::parallel_for(
       Kokkos::RangePolicy<ExecutionSpace>(0, n), KOKKOS_LAMBDA(int i) {
-        points(i) = {{(double)i, (double)i, (double)i}};
+        points(i) = {{(Coordinate)i, (Coordinate)i, (Coordinate)i}};
       });
-  float const delta = 5.f;
-  ArborX::Point const origin = {{0., 0., 0.}};
+#ifdef KOKKOS_COMPILER_NVCC
+  [[maybe_unused]]
+#endif
+  Coordinate const delta = 5.f;
+  Point const origin = {{0., 0., 0.}};
 
   auto values = initialize_values(points, delta);
   std::vector<int> offsets = {0, n};
@@ -317,16 +366,17 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(callback_with_attachment_nearest_predicate,
 
   ARBORX_TEST_QUERY_TREE_CALLBACK(
       ExecutionSpace{}, tree,
-      (makeNearestWithAttachmentQueries<DeviceType, float>({{origin, n}},
-                                                           {delta})),
-      CustomInlineCallbackWithAttachment<DeviceType>{points},
+      (makeNearestWithAttachmentQueries<DeviceType, Point, Coordinate>(
+          {{origin, n}}, {delta})),
+      CustomInlineCallbackWithAttachment<decltype(points)>{points},
       make_compressed_storage(offsets, values));
 
   ARBORX_TEST_QUERY_TREE_CALLBACK(
       ExecutionSpace{}, tree,
-      (makeNearestWithAttachmentQueries<DeviceType, Kokkos::Array<float, 2>>(
+      (makeNearestWithAttachmentQueries<DeviceType, Point,
+                                        Kokkos::Array<Coordinate, 2>>(
           {{origin, n}}, {{0, delta}})),
-      CustomPostCallbackWithAttachment<DeviceType>{points},
+      CustomPostCallbackWithAttachment<decltype(points)>{points},
       make_compressed_storage(offsets, values));
 }
 #endif
