@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -22,16 +22,6 @@
 #include "ArborXTest_TreeTypeTraits.hpp"
 // clang-format on
 
-// We need a forward-declaration for NVCC, see below.
-namespace ArborX
-{
-namespace Experimental
-{
-template <int k>
-struct KDOP;
-}
-} // namespace ArborX
-
 BOOST_AUTO_TEST_SUITE(ManufacturedSolution)
 
 namespace tt = boost::test_tools;
@@ -42,40 +32,46 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(structured_grid, TreeTypeTraits,
   using Tree = typename TreeTypeTraits::type;
   using ExecutionSpace = typename TreeTypeTraits::execution_space;
   using DeviceType = typename TreeTypeTraits::device_type;
+  using BoundingVolume = typename Tree::bounding_volume_type;
+  constexpr int DIM = ArborX::GeometryTraits::dimension_v<BoundingVolume>;
+  using Coordinate = ArborX::GeometryTraits::coordinate_type_t<BoundingVolume>;
+  using Point = ArborX::Point<DIM, Coordinate>;
+  using Box = ArborX::Box<DIM, Coordinate>;
 
   // FIXME_NVCC we see inexplainable test failures with NVCC and KDOP<18> and
   // KDOP<26> here.
 #ifdef __NVCC__
-  if (std::is_same<typename Tree::bounding_volume_type,
-                   ArborX::Experimental::KDOP<18>>::value ||
-      std::is_same<typename Tree::bounding_volume_type,
-                   ArborX::Experimental::KDOP<26>>::value)
-    return;
+  if constexpr (ArborX::GeometryTraits::is_kdop_v<BoundingVolume>)
+  {
+    if constexpr (BoundingVolume::n_directions == 9 ||
+                  BoundingVolume::n_directions == 13)
+      return;
+  }
 #endif
 
-  float Lx = 100.0;
-  float Ly = 100.0;
-  float Lz = 100.0;
+  Coordinate Lx = 100.0;
+  Coordinate Ly = 100.0;
+  Coordinate Lz = 100.0;
   int nx = 11;
   int ny = 11;
   int nz = 11;
   int n = nx * ny * nz;
-  float hx = Lx / (nx - 1);
-  float hy = Ly / (ny - 1);
-  float hz = Lz / (nz - 1);
+  Coordinate hx = Lx / (nx - 1);
+  Coordinate hy = Ly / (ny - 1);
+  Coordinate hz = Lz / (nz - 1);
 
   std::function<int(int, int, int)> ind = [nx, ny](int i, int j, int k) {
     return i + j * nx + k * (nx * ny);
   };
 
-  Kokkos::View<ArborX::Box *, DeviceType> bounding_boxes("bounding_boxes", n);
+  Kokkos::View<Box *, DeviceType> bounding_boxes("bounding_boxes", n);
   auto bounding_boxes_host = Kokkos::create_mirror_view(bounding_boxes);
 
   for (int i = 0; i < nx; ++i)
     for (int j = 0; j < ny; ++j)
       for (int k = 0; k < nz; ++k)
       {
-        ArborX::Point p{{i * hx, j * hy, k * hz}};
+        Point p{{i * hx, j * hy, k * hz}};
         bounding_boxes_host[ind(i, j, k)] = {p, p};
       }
   Kokkos::deep_copy(bounding_boxes, bounding_boxes_host);
@@ -101,8 +97,8 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(structured_grid, TreeTypeTraits,
   std::iota(offset_ref.begin(), offset_ref.end(), 0);
   std::iota(indices_ref.begin(), indices_ref.end(), 0);
 
-  Kokkos::View<decltype(ArborX::intersects(ArborX::Box{})) *, DeviceType>
-      queries("queries", n);
+  Kokkos::View<decltype(ArborX::intersects(Box{})) *, DeviceType> queries(
+      "queries", n);
   Kokkos::parallel_for(
       "fill_queries", Kokkos::RangePolicy<ExecutionSpace>(0, n),
       KOKKOS_LAMBDA(int i) {
@@ -227,7 +223,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(structured_grid, TreeTypeTraits,
   std::uniform_int_distribution<> dist_x(0, nx - 1);
   std::uniform_int_distribution<> dist_y(0, ny - 1);
   std::uniform_int_distribution<> dist_z(0, nz - 1);
-  std::uniform_real_distribution<double> dist_shift(-0.45, 0.45);
+  std::uniform_real_distribution<Coordinate> dist_shift(-0.45, 0.45);
 
   // The generation is a bit convoluted to avoid a situation where a centroid
   // of a box falls on any of the lattice planes, resulting in multiple
@@ -244,8 +240,8 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(structured_grid, TreeTypeTraits,
     auto const x = (i + dist_shift(generator)) * hx;
     auto const y = (j + dist_shift(generator)) * hy;
     auto const z = (k + dist_shift(generator)) * hz;
-    bounding_boxes_host(l) = {{{x - 0.5 * hx, y - 0.5 * hy, z - 0.5 * hz}},
-                              {{x + 0.5 * hx, y + 0.5 * hy, z + 0.5 * hz}}};
+    bounding_boxes_host(l) = {{{x - hx / 2, y - hy / 2, z - hz / 2}},
+                              {{x + hx / 2, y + hy / 2, z + hz / 2}}};
 
     // Save the indices for the check
     indices_ref[l] = ind(i, j, k);
