@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -10,10 +10,11 @@
  ****************************************************************************/
 
 #include "ArborX_EnableDeviceTypes.hpp" // ARBORX_DEVICE_TYPES
-#include <ArborX_DetailsKokkosExtMinMaxReduce.hpp>
-#include <ArborX_DetailsKokkosExtStdAlgorithms.hpp>
-#include <ArborX_DetailsKokkosExtViewHelpers.hpp>
+#include <ArborXTest_LegacyTree.hpp>
 #include <ArborX_LinearBVH.hpp>
+#include <kokkos_ext/ArborX_KokkosExtMinMaxReduce.hpp>
+#include <kokkos_ext/ArborX_KokkosExtStdAlgorithms.hpp>
+#include <kokkos_ext/ArborX_KokkosExtViewHelpers.hpp>
 
 #include <boost/test/unit_test.hpp>
 
@@ -34,16 +35,22 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(buffer_optimization, DeviceType,
   namespace KokkosExt = ArborX::Details::KokkosExt;
 
   using ExecutionSpace = typename DeviceType::execution_space;
+  using MemorySpace = typename DeviceType::memory_space;
 
-  auto const bvh = make<ArborX::BVH<typename DeviceType::memory_space>>(
-      ExecutionSpace{}, {
-                            {{{0., 0., 0.}}, {{0., 0., 0.}}},
-                            {{{1., 0., 0.}}, {{1., 0., 0.}}},
-                            {{{2., 0., 0.}}, {{2., 0., 0.}}},
-                            {{{3., 0., 0.}}, {{3., 0., 0.}}},
-                        });
+  using Box = ArborX::Box<3>;
+  using Tree =
+      LegacyTree<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                                 ArborX::PairValueIndex<Box>>>;
 
-  auto const queries = makeIntersectsBoxQueries<DeviceType>({
+  auto const bvh =
+      make<Tree, Box>(ExecutionSpace{}, {
+                                            {{{0., 0., 0.}}, {{0., 0., 0.}}},
+                                            {{{1., 0., 0.}}, {{1., 0., 0.}}},
+                                            {{{2., 0., 0.}}, {{2., 0., 0.}}},
+                                            {{{3., 0., 0.}}, {{3., 0., 0.}}},
+                                        });
+
+  auto const queries = makeIntersectsQueries<DeviceType, Box>({
       {},
       {{{0., 0., 0.}}, {{3., 3., 3.}}},
       {},
@@ -121,14 +128,21 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(unsorted_predicates, DeviceType,
                               ARBORX_DEVICE_TYPES)
 {
   using ExecutionSpace = typename DeviceType::execution_space;
+  using MemorySpace = typename DeviceType::memory_space;
 
-  auto const bvh = make<ArborX::BVH<typename DeviceType::memory_space>>(
-      ExecutionSpace{}, {
-                            {{{0., 0., 0.}}, {{0., 0., 0.}}},
-                            {{{1., 1., 1.}}, {{1., 1., 1.}}},
-                            {{{2., 2., 2.}}, {{2., 2., 2.}}},
-                            {{{3., 3., 3.}}, {{3., 3., 3.}}},
-                        });
+  using Box = ArborX::Box<3>;
+  using Point = ArborX::Point<3>;
+  using Tree =
+      LegacyTree<ArborX::BoundingVolumeHierarchy<MemorySpace,
+                                                 ArborX::PairValueIndex<Box>>>;
+
+  auto const bvh =
+      make<Tree, Box>(ExecutionSpace{}, {
+                                            {{{0., 0., 0.}}, {{0., 0., 0.}}},
+                                            {{{1., 1., 1.}}, {{1., 1., 1.}}},
+                                            {{{2., 2., 2.}}, {{2., 2., 2.}}},
+                                            {{{3., 3., 3.}}, {{3., 3., 3.}}},
+                                        });
 
   using ViewType = Kokkos::View<int *, DeviceType>;
   ViewType indices("indices", 0);
@@ -148,7 +162,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(unsorted_predicates, DeviceType,
   };
 
   {
-    auto const queries = makeIntersectsBoxQueries<DeviceType>({
+    auto const queries = makeIntersectsQueries<DeviceType, Box>({
         {{{2., 2., 2.}}, {{3., 3., 3.}}},
         {{{0., 0., 0.}}, {{1., 1., 1.}}},
     });
@@ -166,7 +180,7 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(unsorted_predicates, DeviceType,
 
   indices_ref = {2, 3, 0, 1};
   {
-    auto queries = makeNearestQueries<DeviceType>({
+    auto queries = makeNearestQueries<DeviceType, Point>({
         {{{2.5, 2.5, 2.5}}, 2},
         {{{0.5, 0.5, 0.5}}, 2},
     });
