@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2017-2022 by the ArborX authors                            *
+ * Copyright (c) 2025, ArborX authors                                       *
  * All rights reserved.                                                     *
  *                                                                          *
  * This file is part of the ArborX library. ArborX is                       *
@@ -9,18 +9,16 @@
  * SPDX-License-Identifier: BSD-3-Clause                                    *
  ****************************************************************************/
 #include <ArborX_Box.hpp>
-#include <ArborX_HyperTriangle.hpp>
 #include <ArborX_Ray.hpp>
+#include <ArborX_Triangle.hpp>
 
 #include <boost/test/unit_test.hpp>
 
 BOOST_AUTO_TEST_CASE(intersects_box)
 {
-  using ArborX::Box;
-  using ArborX::Point;
   using ArborX::Experimental::Ray;
 
-  constexpr Box unit_box{{0, 0, 0}, {1, 1, 1}};
+  constexpr ArborX::Box unit_box{{0.f, 0.f, 0.f}, {1.f, 1.f, 1.f}};
 
   // origin is within the box
   BOOST_TEST(intersects(Ray{{.5, .5, .5}, {1, 0, 0}}, unit_box));
@@ -178,7 +176,6 @@ BOOST_AUTO_TEST_CASE(intersects_box)
 
 BOOST_AUTO_TEST_CASE(ray_box_intersection, *boost::unit_test::tolerance(1e-6f))
 {
-  using ArborX::Box;
   using ArborX::Experimental::Ray;
 
   namespace KokkosExt = ArborX::Details::KokkosExt;
@@ -188,7 +185,7 @@ BOOST_AUTO_TEST_CASE(ray_box_intersection, *boost::unit_test::tolerance(1e-6f))
   constexpr auto inf = KokkosExt::ArithmeticTraits::infinity<float>::value;
 #endif
 
-  constexpr Box unit_box{{0, 0, 0}, {1, 1, 1}};
+  constexpr ArborX::Box unit_box{{0.f, 0.f, 0.f}, {1.f, 1.f, 1.f}};
 
   auto const sqrtf_5 = std::sqrt(5.f);
   auto const sqrtf_3 = std::sqrt(3.f);
@@ -254,11 +251,10 @@ BOOST_AUTO_TEST_CASE(ray_box_intersection, *boost::unit_test::tolerance(1e-6f))
 
 BOOST_AUTO_TEST_CASE(ray_box_distance)
 {
-  using ArborX::Box;
   using ArborX::Experimental::Ray;
   // use const instead of constexpr because MSVC shows error(error:expression
   // must have a constant value)
-  constexpr Box unit_box{{0, 0, 0}, {1, 1, 1}};
+  constexpr ArborX::Box unit_box{{0.f, 0.f, 0.f}, {1.f, 1.f, 1.f}};
 
   namespace KokkosExt = ArborX::Details::KokkosExt;
 #ifdef _MSC_VER
@@ -281,9 +277,8 @@ BOOST_AUTO_TEST_CASE(ray_box_distance)
 BOOST_AUTO_TEST_CASE(overlap_distance_sphere,
                      *boost::unit_test::tolerance(1e-6f))
 {
-  using ArborX::Sphere;
   using ArborX::Experimental::Ray;
-  constexpr Sphere unit_sphere{{0, 0, 0}, 1};
+  constexpr ArborX::Sphere unit_sphere{{0.f, 0.f, 0.f}, 1.f};
 
   auto const sqrtf_3 = std::sqrt(3.f);
   auto const half_sqrtf_2 = std::sqrt(2.f) / 2;
@@ -367,10 +362,9 @@ BOOST_AUTO_TEST_CASE(overlap_distance_sphere,
 BOOST_AUTO_TEST_CASE(ray_sphere_intersection,
                      *boost::unit_test::tolerance(1e-6f))
 {
-  using ArborX::Sphere;
   using ArborX::Experimental::Ray;
 
-  constexpr Sphere unit_sphere{{0, 0, 0}, 1};
+  constexpr ArborX::Sphere unit_sphere{{0.f, 0.f, 0.f}, 1.f};
   auto const sqrtf_3 = std::sqrt(3.f);
   auto const sqrtf_2 = std::sqrt(2.f);
 
@@ -413,11 +407,11 @@ BOOST_AUTO_TEST_CASE(ray_sphere_intersection,
 
 BOOST_AUTO_TEST_CASE(intersects_triangle)
 {
+  using ArborX::Point;
+  using ArborX::Triangle;
   using ArborX::Experimental::Ray;
-  using ArborX::ExperimentalHyperGeometry::Point;
-  using ArborX::ExperimentalHyperGeometry::Triangle;
-  constexpr Triangle unit_triangle{Point{0, 0, 0}, Point{1, 0, 0},
-                                   Point{0, 1, 0}};
+  constexpr Triangle unit_triangle{
+      {0.f, 0.f, 0.f}, {1.f, 0.f, 0.f}, {0.f, 1.f, 0.f}};
 
   BOOST_TEST(intersects(Ray{{.1, .2, .3}, {0, 0, -1}}, unit_triangle));
   BOOST_TEST(intersects(Ray{{1.1, 1.2, 1}, {-1, -1, -1}}, unit_triangle));
@@ -463,8 +457,8 @@ BOOST_AUTO_TEST_CASE(intersects_triangle)
   // ray in a plane parallel to the triangle
   BOOST_TEST(!intersects(Ray{{-0.1, 0, 1}, {1, 0, 0}}, unit_triangle));
 
-  constexpr Triangle tilted_triangle{Point{0, 0, 0}, Point{2, 0, 1},
-                                     Point{0, 2, 1}};
+  constexpr Triangle tilted_triangle{
+      {0.f, 0.f, 0.f}, {2.f, 0.f, 1.f}, {0.f, 2.f, 1.f}};
 
   // ray in the same plane as the triangle
   BOOST_TEST(!intersects(Ray{{10, 0, 0}, {1, 1, 1}}, tilted_triangle));
@@ -496,9 +490,9 @@ BOOST_AUTO_TEST_CASE(intersects_triangle)
 BOOST_AUTO_TEST_CASE(ray_triangle_intersection,
                      *boost::unit_test::tolerance(2e-6f))
 {
+  using ArborX::Point;
+  using ArborX::Triangle;
   using ArborX::Experimental::Ray;
-  using ArborX::ExperimentalHyperGeometry::Point;
-  using ArborX::ExperimentalHyperGeometry::Triangle;
 
   namespace KokkosExt = ArborX::Details::KokkosExt;
 #ifdef _MSC_VER
@@ -507,10 +501,10 @@ BOOST_AUTO_TEST_CASE(ray_triangle_intersection,
   constexpr auto inf = KokkosExt::ArithmeticTraits::infinity<float>::value;
 #endif
 
-  constexpr Triangle unit_triangle{Point{0, 0, 0}, Point{1, 0, 0},
-                                   Point{0, 1, 0}};
-  constexpr Triangle narrow_triangle{Point{0.5f, 0.5f, 0},
-                                     Point{0.24f, 0.74f, 0}, Point{0, 1.f, 0}};
+  constexpr Triangle unit_triangle{
+      {0.f, 0.f, 0.f}, {1.f, 0.f, 0.f}, {0.f, 1.f, 0.f}};
+  constexpr Triangle narrow_triangle{
+      {0.5f, 0.5f, 0.f}, {0.24f, 0.74f, 0.f}, {0.f, 1.f, 0.f}};
 
   auto const sqrtf_3 = std::sqrt(3.f);
   auto const sqrtf_2 = std::sqrt(2.f);
@@ -564,10 +558,10 @@ BOOST_AUTO_TEST_CASE(ray_triangle_intersection,
   // test would fail the "Plucker coordinates"-based algorithm, thus it is necessary to
   // keep them here to show the watertightness of the current algorithm implemented.
   constexpr Point O{1.f, 1.f, 1.f};
-  constexpr Point A{2.f, 2.f, 0};
-  constexpr Point B{2.f, -1.f, 0};
-  constexpr Point C{-1.f, -1.f, 0};
-  constexpr Point D{-1.f, 2.f, 0};
+  constexpr Point A{2.f, 2.f, 0.f};
+  constexpr Point B{2.f, -1.f, 0.f};
+  constexpr Point C{-1.f, -1.f, 0.f};
+  constexpr Point D{-1.f, 2.f, 0.f};
 
   constexpr Triangle triangle_up{D, A, O};
   constexpr Triangle triangle_right{O, A, B};
@@ -600,12 +594,12 @@ BOOST_AUTO_TEST_CASE(ray_triangle_intersection,
   // between the origin of the ray and the vertices.
   // These tests will fail if there is no normalization.
   float const size_s = 0.0001;
-  Triangle small_triangle{Point{-size_s, 0, 0}, Point{0, size_s, 0}, Point{0, 0, size_s}};
+  Triangle small_triangle{{-size_s, 0.f, 0.f}, {0.f, size_s, 0.f}, {0.f, 0.f, size_s}};
   ARBORX_TEST_RAY_TRIANGLE_INTERSECTION((Ray{{0.0, 0.0, 0.0}, {-size_s, size_s, size_s}}), small_triangle, size_s/sqrtf_3, size_s/sqrtf_3);
   ARBORX_TEST_RAY_TRIANGLE_INTERSECTION((Ray{{-2.f*size_s, -size_s, 0.0}, {size_s, size_s, 0}}), small_triangle, sqrtf_2*size_s, 2.f*sqrtf_2*size_s);
 
   float const size_l = 10000;
-  Triangle large_triangle{Point{-size_l, 0, 0}, Point{0, 10000, 0}, Point{0, 0, 10000}};
+  Triangle large_triangle{{-size_l, 0.f, 0.f}, {0.f, 10000.f, 0.f}, {0.f, 0.f, 10000.f}};
   ARBORX_TEST_RAY_TRIANGLE_INTERSECTION((Ray{{0.0, 0.0, 0.0}, {-size_l, size_l, size_l}}), large_triangle, size_l/sqrtf_3, size_l/sqrtf_3);
   ARBORX_TEST_RAY_TRIANGLE_INTERSECTION((Ray{{-2.f*size_l, -size_l, 0.0}, {size_l, size_l, 0}}), large_triangle, sqrtf_2*size_l, 2.f*sqrtf_2*size_l);
 
@@ -614,35 +608,3 @@ BOOST_AUTO_TEST_CASE(ray_triangle_intersection,
 
 #undef ARBORX_TEST_RAY_TRIANGLE_INTERSECTION
 #undef ARBORX_TEST_RAY_TRIANGLE_NO_INTERSECTION
-
-BOOST_AUTO_TEST_CASE(make_euclidean_vector)
-{
-  using ArborX::Experimental::makeVector;
-  using ArborX::Experimental::Vector;
-  using ArborX::ExperimentalHyperGeometry::Point;
-  static_assert(makeVector(Point{0, 0, 0}, Point{1, 2, 3}) == Vector{1, 2, 3});
-  static_assert(makeVector(Point{1, 2, 3}, Point{4, 5, 6}) == Vector{3, 3, 3});
-}
-
-BOOST_AUTO_TEST_CASE(dot_product)
-{
-  using ArborX::Experimental::dotProduct;
-  static_assert(dotProduct({1, 0, 0}, {1, 0, 0}) == 1);
-  static_assert(dotProduct({1, 0, 0}, {0, 1, 0}) == 0);
-  static_assert(dotProduct({1, 0, 0}, {0, 0, 1}) == 0);
-  static_assert(dotProduct({1, 1, 1}, {1, 1, 1}) == 3);
-}
-
-BOOST_AUTO_TEST_CASE(cross_product)
-{
-  using ArborX::Experimental::crossProduct;
-  using ArborX::Experimental::Vector;
-  static_assert(crossProduct({1, 0, 0}, {1, 0, 0}) == Vector{0, 0, 0});
-  static_assert(crossProduct({1, 0, 0}, {0, 1, 0}) == Vector{0, 0, 1});
-  static_assert(crossProduct({1, 0, 0}, {0, 0, 1}) == Vector{0, -1, 0});
-  static_assert(crossProduct({0, 1, 0}, {1, 0, 0}) == Vector{0, 0, -1});
-  static_assert(crossProduct({0, 1, 0}, {0, 1, 0}) == Vector{0, 0, 0});
-  static_assert(crossProduct({0, 1, 0}, {0, 0, 1}) == Vector{1, 0, 0});
-  static_assert(crossProduct({1, 1, 1}, {1, 1, 1}) == Vector{0, 0, 0});
-}
-#undef static_assert
